@@ -106,7 +106,11 @@ int describe_table(OGRLayerH hLayer, dbTable **table, cursor *c)
 	ogrType = OGR_Fld_GetType(hFieldDefn);
 	fieldName = OGR_Fld_GetNameRef(hFieldDefn);
 
-	if (ogrType != OFTInteger && ogrType != OFTReal &&
+	if (ogrType != OFTInteger &&
+#if GDAL_VERSION_NUM >= 2000000
+            ogrType != OFTInteger64 &&
+#endif
+            ogrType != OFTReal &&
 	    ogrType != OFTString  && ogrType != OFTDate &&
 	    ogrType != OFTTime    && ogrType != OFTDateTime ) {
 	    G_warning(_("OGR driver: column '%s', OGR type %d is not supported"),
@@ -171,9 +175,17 @@ int describe_table(OGRLayerH hLayer, dbTable **table, cursor *c)
 
 	switch (ogrType) {
 	case OFTInteger:
+#if GDAL_VERSION_NUM >= 2000000
+        case OFTInteger64:
+#endif
 	    sqlType = DB_SQL_TYPE_INTEGER;
 	    size = OGR_Fld_GetWidth(hFieldDefn);	/* OK ? */
 	    precision = 0;
+#if GDAL_VERSION_NUM >= 2000000
+            if (ogrType == OFTInteger64)
+                G_warning(_("Column '%s' : type int8 (bigint) is stored as integer (4 bytes) "
+                            "some data may be damaged"), fieldName);
+#endif
 	    break;
 
 	case OFTReal:
