@@ -12,6 +12,18 @@
  *
  *****************************************************************************/
 
+/*
+ Functionality:
+
+ d.mon delegates rendering to Python script [1] through GRASS_RENDER_COMMAND [2].
+ See also document [3].
+
+ [1] https://trac.osgeo.org/grass/browser/grass/trunk/display/d.mon/render_cmd.py
+ [2] https://trac.osgeo.org/grass/browser/grass/trunk/lib/display/r_raster.c#L107
+ [3] https://grass.osgeo.org/grass74/manuals/displaydrivers.html
+
+*/
+
 #include <stdlib.h>
 #include <string.h>
 
