@@ -1,9 +1,13 @@
 #include <grass/gis.h>
 #include "options.h"
+#include "local_proto.h"
 
-void normal(char *mapset, struct Cell_head *window, struct Categories *cats,
+void normal(struct Cell_head *window, struct Categories *cats,
 	    int simple, FILE * fp)
 {
+    char xname[GNAME_MAX], xmapset[GMAPSET_MAX];
+
+    G_unqualified_name(map_name, G_mapset(), xname, xmapset);
 
     fprintf(fp, ".C %s\n", color);
     fprintf(fp, ".S %f\n", size);
@@ -13,7 +17,7 @@ void normal(char *mapset, struct Cell_head *window, struct Categories *cats,
     }
     else {
 	fprintf(fp, "LOCATION: %s\n", G_location());
-	fprintf(fp, "%s in %s\n", map_name, mapset);
+	fprintf(fp, "%s in %s\n", xname, xmapset);
 	fprintf(fp, "%s\n", cats->title);
 	fprintf(fp, "North: %10.2f  South: %10.2f\n",
 		window->north, window->south);
