@@ -1,5 +1,9 @@
+
+#ifndef PLOT_H_
+#define PLOT_H_
 /* TODO: should use 24bit instead of 16 colors, maybe implement
    predefined color tables? */
+
 struct rgb_color
 {
     unsigned char R, G, B;
@@ -15,7 +19,8 @@ typedef struct
     int has_bcolor;
     struct rgb_color color, bgcolor, bcolor;
     int size;
-    char *font;
+    const char *font;
+    const char *enc;
     int xref, yref;
 } LATTR;
 
@@ -29,14 +34,15 @@ typedef struct
 #define DISP_SHAPE 0x01
 #define DISP_CAT   0x02
 #define DISP_TOPO  0x04
-#define DISP_DIR   0x08
-#define DISP_ATTR  0x10
+#define DISP_VERT  0x08
+#define DISP_DIR   0x10
 #define DISP_ZCOOR 0x20
 
-#define RENDER_GPP	0
-#define RENDER_RPA	1
 #define RENDER_DP	2
 #define RENDER_DPC	3
 #define RENDER_DPL	4
 
 extern int render;
+
+#endif
+
