@@ -180,14 +180,14 @@ void print_wkt(int esristyle, int dontprettify)
     if (check_xy(FALSE))
 	return;
 
-    outwkt = GPJ_grass_to_wkt(projinfo, projunits, esristyle,
+    outwkt = GPJ_grass_to_wkt2(projinfo, projunits, projepsg, esristyle,
 			      !(dontprettify));
     if (outwkt != NULL) {
 	fprintf(stdout, "%s\n", outwkt);
 	G_free(outwkt);
     }
     else
-	G_warning(_("%s: Unable to convert to WKT"), G_program_name());
+	G_warning(_("Unable to convert to WKT"));
 
     return;
 }
