@@ -30,6 +30,7 @@ int main(int argc, char *argv[])
 {
     int i;
     int print_flag = 0;
+    int flat_flag; 
     int set_flag;
     double x;
     int ival;
@@ -44,7 +45,7 @@ int main(int argc, char *argv[])
     struct
     {
 	struct Flag
-	    *update, *print, *gprint, *lprint, *eprint, *nangle,
+	    *update, *print, *gprint, *flprint, *lprint, *eprint, *nangle,
 	    *center, *res_set, *dist_res, *dflt, *z, *savedefault,
 	    *bbox, *gmt_style, *wms_style;
     } flag;
@@ -65,6 +66,7 @@ int main(int argc, char *argv[])
     G_add_keyword(_("computational region"));
     G_add_keyword(_("extent"));
     G_add_keyword(_("resolution"));
+    G_add_keyword(_("level1"));
     module->description =
 	_("Manages the boundary definitions for the " "geographic region.");
 
@@ -145,6 +147,11 @@ int main(int argc, char *argv[])
     flag.gprint->description = _("Print in shell script style");
     flag.gprint->guisection = _("Print");
 
+    flag.flprint = G_define_flag();
+    flag.flprint->key = 'f';
+    flag.flprint->description = _("Print in shell script style, but in one line (flat)");
+    flag.flprint->guisection = _("Print");
+
     flag.res_set = G_define_flag();
     flag.res_set->key = 'a';
     flag.res_set->description =
@@ -354,6 +361,7 @@ int main(int argc, char *argv[])
     G_get_default_window(&window);
 
     set_flag = !flag.update->answer;
+    flat_flag = flag.flprint->answer;
 
     if (flag.print->answer)
 	print_flag |= PRINT_REG;
@@ -459,6 +467,7 @@ int main(int argc, char *argv[])
 
 	vect_ptr = parm.vect->answers;
 	for (; *vect_ptr != NULL; vect_ptr++) {
+            int ret;
 	    struct Map_info Map;
 	    struct bound_box box;
 	    char vect_name[GNAME_MAX];
@@ -480,46 +489,15 @@ int main(int argc, char *argv[])
                     G_fatal_error(_("Unable to open vector map <%s>"),
                                   vect_name);
             }
+
+            ret = 0;
+            if (Vect_level(&Map) > 1)            /* level 2 - topology available */
+                ret = Vect_get_map_box(&Map, &box);
+            else                                 /* level 1 */
+                ret = Vect_get_map_box1(&Map, &box);
+            if (ret != 1)
+                G_fatal_error(_("Unable to get map bounding box"));
             
-            if (Vect_level(&Map) > 1) {
-                /* topology available */
-                Vect_get_map_box(&Map, &box);
-            }
-            else {
-                /* no topology
-                   NOTE: number of points, lines, boundaries,
-                   centroids, faces, kernels is still available */
-
-                int type;
-                int first = TRUE;
-                struct line_pnts *Points;
-                struct bound_box line_box;
-
-                Points = Vect_new_line_struct();
-                Vect_rewind(&Map);
-                G_message(_("Topology not available for vector map <%s>. "
-                            "Registering primitives..."), vect_name);
-                while (TRUE) {
-                    /* register line */
-                    type = Vect_read_next_line(&Map, Points, NULL);
-                    
-                    if (type == -1) {
-                        G_fatal_error(_("Unable to read vector map"));
-                    }
-                    else if (type == -2) {
-                        break;
-                    }
-                    dig_line_box(Points, &line_box);
-                    if (first == TRUE) {
-                        Vect_box_copy(&box, &line_box);
-                        first = FALSE;
-                    }
-                    else
-                        Vect_box_extend(&box, &line_box);
-                }
-                Vect_destroy_line_struct(Points);
-            }
-
             map_window = window;
             map_window.north = box.N;
             map_window.south = box.S;
@@ -824,7 +802,7 @@ int main(int argc, char *argv[])
 
 
     if (print_flag)
-	print_window(&window, print_flag);
+	print_window(&window, print_flag, flat_flag);
 
     exit(EXIT_SUCCESS);
 }
