@@ -57,78 +57,46 @@ int main(int argc, char *argv[])
     int stat;
     char cmnd2[500];
     char proj_out[20], proj_name[50], set_name[20];
-    char path[GPATH_MAX], buffa[1024], buffb[1024], answer[200], answer1[200];
+    char path[1024], buffa[1024], buffb[1024], answer[200], answer1[200];
     char answer2[200], buff[1024];
     char tmp_buff[20], *buf;
 
     struct Key_Value *old_proj_keys, *out_proj_keys, *in_unit_keys;
     double aa, e2;
     double f;
-    FILE *FPROJ, *fp;
+    FILE *FPROJ;
     int exist = 0;
     char spheroid[100];
     int j, k, sph_check;
     struct Cell_head cellhd;
     char datum[100], dat_ellps[100], dat_params[100];
     struct proj_parm *proj_parms;
-    struct Option *set_myname;
-    struct Flag *print_myname;
-
 
     G_gisinit(argv[0]);
 
     module = G_define_module();
-    module->keywords = _("general, projection");
+    G_add_keyword(_("general"));
+    G_add_keyword(_("projection"));
     module->description =
 	_("Interactively reset the location's projection settings.");
 
-    set_myname = G_define_option();
-    set_myname->key = "description";
-    set_myname->key_desc = "\"phrase\"";
-    set_myname->type = TYPE_STRING;
-    set_myname->required = NO;
-    set_myname->description =
-	_("Reset the location's one line description with this text, then exit");
-
-    print_myname = G_define_flag();
-    print_myname->key = 'n';
-    print_myname->description =
-        _("Print the location's one line description and exit");
-
-    if (argc > 1 && G_parser(argc, argv))
+    if (G_parser(argc, argv))
 	exit(EXIT_FAILURE);
 
 
-    if (print_myname->answer) {
-	fprintf(stdout, "%s\n", G_myname());
-	exit(EXIT_SUCCESS);
-    }
-
     if (strcmp(G_mapset(), "PERMANENT") != 0)
 	G_fatal_error(_("You must be in the PERMANENT mapset to run g.setproj"));
 
-    if (set_myname->answer) {
-	fp = G_fopen_new(".", "MYNAME");
-	if (strlen(set_myname->answer) > RECORD_LEN-1)
-	    G_warning(_("Text shortened to first %d characters"), RECORD_LEN-1);
-	strncpy(buffa, set_myname->answer, RECORD_LEN-1);
-	buffa[RECORD_LEN-1] = '\0';
-	G_squeeze(buffa);
-	fputs(buffa, fp);
-	fclose(fp);
-	exit(EXIT_SUCCESS);
-    }
-
 	/***
-	  * no longer necessary, table is a static struct
+         * no longer necessary, table is a static struct 
 	 * init_unit_table();
         ***/
     sprintf(set_name, "PERMANENT");
-    G__file_name(path, "", PROJECTION_FILE, set_name);
+    G_file_name(path, "", PROJECTION_FILE, set_name);
 
     /* get the output projection parameters, if existing */
     /* Check for ownership here */
-    stat = G__mapset_permissions(set_name);
+    stat = G_mapset_permissions(set_name);
     if (stat == 0) {
 	G_fatal_error(_("PERMANENT: permission denied"));
     }
@@ -193,19 +161,19 @@ int main(int argc, char *argv[])
 	}
     case PROJECTION_UTM:
 	if (!exist) {
-	    sprintf(proj_name, "%s", G__projection_name(PROJECTION_UTM));
+	    sprintf(proj_name, "%s", G_projection_name(PROJECTION_UTM));
 	    sprintf(proj_out, "utm");
 	    break;
 	}
     case PROJECTION_SP:
 	if (!exist) {
-	    sprintf(proj_name, "%s", G__projection_name(PROJECTION_SP));
+	    sprintf(proj_name, "%s", G_projection_name(PROJECTION_SP));
 	    sprintf(proj_out, "stp");
 	    break;
 	}
     case PROJECTION_LL:
 	if (!exist) {
-	    sprintf(proj_name, "%s", G__projection_name(PROJECTION_LL));
+	    sprintf(proj_name, "%s", G_projection_name(PROJECTION_LL));
 	    sprintf(proj_out, "ll");
 	    break;
 	}
@@ -279,7 +247,7 @@ int main(int argc, char *argv[])
     }
     else {
 
-	/*****************   GET spheroid  **************************/
+/*****************   GET spheroid  **************************/
 
 	if (Out_proj != PROJECTION_SP) {	/* some projections have 
 						 * fixed spheroids */
@@ -351,7 +319,7 @@ int main(int argc, char *argv[])
 		    radius =
 			prompt_num_double(_("Enter radius for the sphere in meters"),
 					  RADIUS_DEF, 1);
-	    }	/* end ask radius */
+	    }			/* end ask radius */
 	}
     }
 
@@ -519,7 +487,7 @@ int main(int argc, char *argv[])
 		    G_set_key_value(desc->key, tmp_buff, out_proj_keys);
 		}
 	    }
-	}	/* for OPTIONS */
+	}			/* for OPTIONS */
     }
 
     /* create the PROJ_INFO & PROJ_UNITS files, if required */
@@ -534,7 +502,7 @@ int main(int argc, char *argv[])
 	G_free_key_value(old_proj_keys);
 
   write_units:
-    G__file_name(path, "", UNIT_FILE, set_name);
+    G_file_name(path, "", UNIT_FILE, set_name);
 
     /* if we got this far, the user
      ** already affirmed to write over old info
@@ -671,7 +639,7 @@ int main(int argc, char *argv[])
 	G_free_key_value(in_unit_keys);
     }				/* if */
 
-    if (G__put_window(&cellhd, "", "DEFAULT_WIND") < 0)
+    if (G_put_element_window(&cellhd, "", "DEFAULT_WIND") < 0)
 	G_fatal_error(_("Unable to write to DEFAULT_WIND region file"));
     fprintf(stderr,
 	    _("\nProjection information has been recorded for this location\n\n"));
