@@ -10,7 +10,7 @@ Classes:
 from core.debug import Debug
 Debug.msg (3, 'debug message')
 @endcode
-         
+
 (C) 2007-2009, 2011 by the GRASS Development Team
 
 This program is free software under the GNU General Public License
@@ -24,23 +24,34 @@ import sys
 
 import grass.script as grass
 
+
 class DebugMsg:
     """wxGUI debugging
-    
+
         g.gisenv set=WX_DEBUG=[0-5]
 
     """
+
     def __init__(self):
         # default level
         self.debuglevel = 0
-        
+
         self.SetLevel()
 
     def SetLevel(self):
         """Initialize gui debug level
         """
-        self.debuglevel = int(grass.gisenv().get('WX_DEBUG', 0))
-        
+        try:
+            self.debuglevel = int(grass.gisenv().get('WX_DEBUG', 0))
+            if self.debuglevel < 0 or self.debuglevel > 5:
+                raise ValueError(
+                    _("Wx debug level {0}.").format(
+                        self.debuglevel))
+        except ValueError as e:
+            self.debuglevel = 0
+            sys.stderr.write(
+                _("WARNING: Ignoring unsupported wx debug level (must be >=0 and <=5). {0}\n").format(e))
+
     def msg(self, level, message, *args):
         """Print debug message
 
@@ -51,13 +62,13 @@ class DebugMsg:
         # self.SetLevel()
         if self.debuglevel > 0 and level > 0 and level <= self.debuglevel:
             if args:
-                sys.stderr.write("GUI D%d/%d: " % (level, self.debuglevel) + \
-                    message % args + os.linesep)
+                sys.stderr.write("GUI D%d/%d: " % (level, self.debuglevel) +
+                                 message % args + os.linesep)
             else:
-                sys.stderr.write("GUI D%d/%d: " % (level, self.debuglevel) + \
-                                     message + os.linesep)
-            sys.stderr.flush() # force flush (required for MS Windows)
-        
+                sys.stderr.write("GUI D%d/%d: " % (level, self.debuglevel) +
+                                 message + os.linesep)
+            sys.stderr.flush()  # force flush (required for MS Windows)
+
     def GetLevel(self):
         """Return current GUI debug level"""
         return self.debuglevel
