@@ -1070,10 +1070,10 @@ def PilImageToWxImage(pilImage, copyAlpha=True):
 
     Based on http://wiki.wxpython.org/WorkingWithImages
     """
-    import wx
+    from gui_core.wrap import EmptyImage
     hasAlpha = pilImage.mode[-1] == 'A'
     if copyAlpha and hasAlpha:  # Make sure there is an alpha layer copy.
-        wxImage = wx.EmptyImage(*pilImage.size)
+        wxImage = EmptyImage(*pilImage.size)
         pilImageCopyRGBA = pilImage.copy()
         pilImageCopyRGB = pilImageCopyRGBA.convert('RGB')    # RGBA --> RGB
         fn = getattr(
@@ -1091,10 +1091,13 @@ def PilImageToWxImage(pilImage, copyAlpha=True):
                 pilImageCopyRGBA,
                 "tostring"))
         # Create layer and insert alpha values.
-        wxImage.SetAlphaData(fn()[3::4])
+        if globalvar.wxPythonPhoenix:
+            wxImage.SetAlpha(fn()[3::4])
+        else:
+            wxImage.SetAlphaData(fn()[3::4])
 
     else:    # The resulting image will not have alpha.
-        wxImage = wx.EmptyImage(*pilImage.size)
+        wxImage = EmptyImage(*pilImage.size)
         pilImageCopy = pilImage.copy()
         # Discard any alpha from the PIL image.
         pilImageCopyRGB = pilImageCopy.convert('RGB')
