@@ -160,6 +160,8 @@ class ProcessWorkspaceFile:
                 "render": bool(int(display.get('render', "0"))),
                 "mode": int(display.get('mode', 0)),
                 "showCompExtent": bool(int(display.get('showCompExtent', "0"))),
+                "showStatusbar": bool(int(display.get('showStatusbar', "0"))),
+                "showToolbars": bool(int(display.get('showToolbars', "0"))),
                 "pos": pos,
                 "size": size,
                 "extent": extent,
@@ -848,6 +850,8 @@ class WriteWorkspaceFile(object):
                        'mode="%d" showCompExtent="%d" '
                        'alignExtent="%d" '
                        'constrainRes="%d" '
+                       'showStatusbar="%d" '
+                       'showToolbars="%d" '
                        'dim="%d,%d,%d,%d" '
                        'extent="%f,%f,%f,%f,%f,%f" '
                        'tbres="%f" '  # needed only for animation tool
@@ -858,6 +862,8 @@ class WriteWorkspaceFile(object):
                                               int(mapdisp.mapWindowProperties.showRegion),
                                               int(mapdisp.mapWindowProperties.alignExtent),
                                               int(mapdisp.mapWindowProperties.resolution),
+                                              int(mapdisp.statusbarManager.IsShown()),
+                                              int(mapdisp.GetMapToolbar().IsShown()),
                                               displayPos[0],
                                               displayPos[1],
                                               displaySize[0],
@@ -984,7 +990,7 @@ class WriteWorkspaceFile(object):
                         self.indent += 4
                         self.file.write(
                             '%s<value>%s</value>\n' %
-                            (' ' * self.indent, self.__filterValue(val)))
+                            (' ' * self.indent, EncodeString(self.__filterValue(val))))
                         self.indent -= 4
                         self.file.write(
                             '%s</parameter>\n' %
@@ -1567,7 +1573,7 @@ class WriteWorkspaceFile(object):
             else:
                 self.file.write('%s<parameter name="%s">\n' % (' ' * self.indent, prm.split("=", 1)[0]))
                 self.indent += 4
-                self.file.write('%s<value>%s</value>\n' % (' ' * self.indent, prm.split("=", 1)[1]))
+                self.file.write('%s<value>%s</value>\n' % (' ' * self.indent, EncodeString(prm.split("=", 1)[1])))
                 self.indent -= 4
                 self.file.write('%s</parameter>\n' % (' ' * self.indent))
         self.indent -= 4
