@@ -21,29 +21,30 @@ import time
 
 import grass.script as grass
 
-from gui_core.mapdisp   import DoubleMapFrame
-from gui_core.dialogs   import GetImageHandlers
+from gui_core.mapdisp import DoubleMapFrame
+from gui_core.dialogs import GetImageHandlers
 from mapwin.base import MapWindowProperties
 from core import globalvar
-from core.render        import Map
-from mapdisp            import statusbar as sb
-from core.debug         import Debug
-from core.gcmd          import GError, GMessage
+from core.render import Map
+from mapdisp import statusbar as sb
+from core.debug import Debug
+from core.gcmd import GError, GMessage
 from core.utils import _
 from core.layerlist import LayerListToRendererConverter
 from gui_core.query import QueryDialog, PrepareQueryResults
 
-from mapswipe.toolbars  import SwipeMapToolbar, SwipeMainToolbar, SwipeMiscToolbar
+from mapswipe.toolbars import SwipeMapToolbar, SwipeMainToolbar, SwipeMiscToolbar
 from mapswipe.mapwindow import SwipeBufferedWindow
-from mapswipe.dialogs   import SwipeMapDialog, PreferencesDialog
+from mapswipe.dialogs import SwipeMapDialog, PreferencesDialog
 
 
 class SwipeMapFrame(DoubleMapFrame):
-    def __init__(self, parent  = None, giface = None, 
-                 title = _("GRASS GIS Map Swipe"), name = "swipe", **kwargs):
-        DoubleMapFrame.__init__(self, parent = parent, title = title, name = name,
-                                firstMap = Map(), secondMap = Map(), **kwargs)
-        Debug.msg (1, "SwipeMapFrame.__init__()")
+
+    def __init__(self, parent=None, giface=None,
+                 title=_("GRASS GIS Map Swipe"), name="swipe", **kwargs):
+        DoubleMapFrame.__init__(self, parent=parent, title=title, name=name,
+                                firstMap=Map(), secondMap=Map(), **kwargs)
+        Debug.msg(1, "SwipeMapFrame.__init__()")
         #
         # Add toolbars
         #
@@ -59,29 +60,34 @@ class SwipeMapFrame(DoubleMapFrame):
         #
         # create widgets
         #
-        self.splitter = MapSplitter(parent = self, id = wx.ID_ANY)
+        self.splitter = MapSplitter(parent=self, id=wx.ID_ANY)
+
+        self.sliderH = wx.Slider(self, id=wx.ID_ANY, style=wx.SL_HORIZONTAL)
+        self.sliderV = wx.Slider(self, id=wx.ID_ANY, style=wx.SL_VERTICAL)
 
-        self.sliderH = wx.Slider(self, id = wx.ID_ANY, style = wx.SL_HORIZONTAL)
-        self.sliderV = wx.Slider(self, id = wx.ID_ANY, style = wx.SL_VERTICAL)
-        
         self.mapWindowProperties = MapWindowProperties()
         self.mapWindowProperties.setValuesFromUserSettings()
-        self.mapWindowProperties.autoRenderChanged.connect(self.OnAutoRenderChanged)
-        self.firstMapWindow = SwipeBufferedWindow(parent = self.splitter, giface = self._giface,
-                                                  properties=self.mapWindowProperties,
-                                                  Map = self.firstMap)
-        self.secondMapWindow = SwipeBufferedWindow(parent = self.splitter, giface = self._giface,
-                                                   properties=self.mapWindowProperties,
-                                                   Map = self.secondMap)
+        self.mapWindowProperties.autoRenderChanged.connect(
+            self.OnAutoRenderChanged)
+        self.firstMapWindow = SwipeBufferedWindow(
+            parent=self.splitter, giface=self._giface,
+            properties=self.mapWindowProperties, Map=self.firstMap)
+        self.secondMapWindow = SwipeBufferedWindow(
+            parent=self.splitter, giface=self._giface,
+            properties=self.mapWindowProperties, Map=self.secondMap)
         # bind query signal
         self.firstMapWindow.mapQueried.connect(self.Query)
         self.secondMapWindow.mapQueried.connect(self.Query)
 
         # bind tracking cursosr to mirror it
-        self.firstMapWindow.Bind(wx.EVT_MOTION, lambda evt: self.TrackCursor(evt))
-        self.secondMapWindow.Bind(wx.EVT_MOTION, lambda evt: self.TrackCursor(evt))
+        self.firstMapWindow.Bind(
+            wx.EVT_MOTION,
+            lambda evt: self.TrackCursor(evt))
+        self.secondMapWindow.Bind(
+            wx.EVT_MOTION,
+            lambda evt: self.TrackCursor(evt))
 
-        self.MapWindow = self.firstMapWindow # current by default
+        self.MapWindow = self.firstMapWindow  # current by default
         self.firstMapWindow.zoomhistory = self.secondMapWindow.zoomhistory
         self.SetBindRegions(True)
 
@@ -102,8 +108,8 @@ class SwipeMapFrame(DoubleMapFrame):
         self.Bind(wx.EVT_IDLE, self.OnIdle)
         self.Bind(wx.EVT_CLOSE, self.OnCloseWindow)
 
-        self.SetSize((825, 600))
-        
+        self.SetSize((800, 600))
+
         self._mgr.Update()
 
         self.rasters = {'first': None, 'second': None}
@@ -135,14 +141,14 @@ class SwipeMapFrame(DoubleMapFrame):
 
         event.Skip()
 
-    def ActivateFirstMap(self, event = None):
+    def ActivateFirstMap(self, event=None):
         """Switch tracking direction"""
         super(SwipeMapFrame, self).ActivateFirstMap(event)
 
         self.firstMapWindow.ClearLines()
         self.firstMapWindow.Refresh()
 
-    def ActivateSecondMap(self, event = None):
+    def ActivateSecondMap(self, event=None):
         """Switch tracking direction"""
         super(SwipeMapFrame, self).ActivateSecondMap(event)
 
@@ -151,11 +157,12 @@ class SwipeMapFrame(DoubleMapFrame):
 
     def CallAfterInit(self):
         self.InitSliderBindings()
-        self.splitter.SplitVertically(self.firstMapWindow, self.secondMapWindow, 0)
+        self.splitter.SplitVertically(
+            self.firstMapWindow, self.secondMapWindow, 0)
         self.splitter.Init()
         if not (self.rasters['first'] and self.rasters['second']):
             self.OnSelectLayers(event=None)
-        
+
     def InitStatusbar(self):
         """Init statusbar (default items)."""
         # items for choice
@@ -169,20 +176,23 @@ class SwipeMapFrame(DoubleMapFrame):
                                sb.SbMapScale,
                                sb.SbGoTo,
                                sb.SbProjection]
-        
+
         # create statusbar and its manager
-        statusbar = self.CreateStatusBar(number = 4, style = 0)
+        statusbar = self.CreateStatusBar(number=4, style=0)
         if globalvar.wxPython3:
             statusbar.SetMinHeight(24)
         statusbar.SetStatusWidths([-5, -2, -1, -1])
-        self.statusbarManager = sb.SbManager(mapframe = self, statusbar = statusbar)
-        
+        self.statusbarManager = sb.SbManager(
+            mapframe=self, statusbar=statusbar)
+
         # fill statusbar manager
-        self.statusbarManager.AddStatusbarItemsByClass(self.statusbarItems, mapframe = self, statusbar = statusbar)
-        self.statusbarManager.AddStatusbarItem(sb.SbMask(self, statusbar = statusbar, position = 2))
-        sbRender = sb.SbRender(self, statusbar = statusbar, position = 3)
+        self.statusbarManager.AddStatusbarItemsByClass(
+            self.statusbarItems, mapframe=self, statusbar=statusbar)
+        self.statusbarManager.AddStatusbarItem(
+            sb.SbMask(self, statusbar=statusbar, position=2))
+        sbRender = sb.SbRender(self, statusbar=statusbar, position=3)
         self.statusbarManager.AddStatusbarItem(sbRender)
-        
+
         self.statusbarManager.Update()
 
     def ResetSlider(self):
@@ -193,19 +203,25 @@ class SwipeMapFrame(DoubleMapFrame):
         self.slider.SetRange(0, size)
         self.slider.SetValue(self.splitter.GetSashPosition())
 
-
     def InitSliderBindings(self):
         self.sliderH.Bind(wx.EVT_SPIN, self.OnSliderPositionChanging)
-        self.sliderH.Bind(wx.EVT_SCROLL_THUMBRELEASE, self.OnSliderPositionChanged)
+        self.sliderH.Bind(
+            wx.EVT_SCROLL_THUMBRELEASE,
+            self.OnSliderPositionChanged)
         self.sliderV.Bind(wx.EVT_SPIN, self.OnSliderPositionChanging)
-        self.sliderV.Bind(wx.EVT_SCROLL_THUMBRELEASE, self.OnSliderPositionChanged)
-        self.splitter.Bind(wx.EVT_SPLITTER_SASH_POS_CHANGING, self.OnSashChanging)
-        self.splitter.Bind(wx.EVT_SPLITTER_SASH_POS_CHANGED, self.OnSashChanged)
-
+        self.sliderV.Bind(
+            wx.EVT_SCROLL_THUMBRELEASE,
+            self.OnSliderPositionChanged)
+        self.splitter.Bind(
+            wx.EVT_SPLITTER_SASH_POS_CHANGING,
+            self.OnSashChanging)
+        self.splitter.Bind(
+            wx.EVT_SPLITTER_SASH_POS_CHANGED,
+            self.OnSashChanged)
 
     def OnSliderPositionChanging(self, event):
         """Slider changes its position, sash must be moved too."""
-        Debug.msg (5, "SwipeMapFrame.OnSliderPositionChanging()")
+        Debug.msg(5, "SwipeMapFrame.OnSliderPositionChanging()")
 
         self.GetFirstWindow().movingSash = True
         self.GetSecondWindow().movingSash = True
@@ -217,27 +233,27 @@ class SwipeMapFrame(DoubleMapFrame):
 
     def OnSliderPositionChanged(self, event):
         """Slider position changed, sash must be moved too."""
-        Debug.msg (5, "SwipeMapFrame.OnSliderPositionChanged()")
+        Debug.msg(5, "SwipeMapFrame.OnSliderPositionChanged()")
 
         self.splitter.SetSashPosition(event.GetPosition())
         self.splitter.OnSashChanged(None)
 
     def OnSashChanging(self, event):
         """Sash position is changing, slider must be moved too."""
-        Debug.msg (5, "SwipeMapFrame.OnSashChanging()")
+        Debug.msg(5, "SwipeMapFrame.OnSashChanging()")
 
         self.slider.SetValue(self.splitter.GetSashPosition())
         event.Skip()
 
     def OnSashChanged(self, event):
         """Sash position changed, slider must be moved too."""
-        Debug.msg (5, "SwipeMapFrame.OnSashChanged()")
+        Debug.msg(5, "SwipeMapFrame.OnSashChanged()")
 
         self.OnSashChanging(event)
         event.Skip()
 
     def OnSize(self, event):
-        Debug.msg (4, "SwipeMapFrame.OnSize()")
+        Debug.msg(4, "SwipeMapFrame.OnSize()")
         self.resize = time.clock()
         super(SwipeMapFrame, self).OnSize(event)
 
@@ -249,7 +265,7 @@ class SwipeMapFrame(DoubleMapFrame):
             sizeAll = self.splitter.GetSize()
             w1.SetClientSize(sizeAll)
             w2.SetClientSize(sizeAll)
-            
+
             w1.OnSize(event)
             w2.OnSize(event)
             self.ResetSlider()
@@ -263,7 +279,7 @@ class SwipeMapFrame(DoubleMapFrame):
 
     def AddToolbar(self, name):
         """Add defined toolbar to the window
-        
+
         Currently known toolbars are:
          - 'swipeMap'          - basic map toolbar
          - 'swipeMain'         - swipe functionality
@@ -271,60 +287,60 @@ class SwipeMapFrame(DoubleMapFrame):
         if name == "swipeMap":
             self.toolbars[name] = SwipeMapToolbar(self, self._toolSwitcher)
             self._mgr.AddPane(self.toolbars[name],
-                      wx.aui.AuiPaneInfo().
-                      Name(name).Caption(_("Map Toolbar")).
-                      ToolbarPane().Top().
-                      LeftDockable(False).RightDockable(False).
-                      BottomDockable(False).TopDockable(True).
-                      CloseButton(False).Layer(2).Row(1).
-                      BestSize((self.toolbars[name].GetBestSize())))
+                              wx.aui.AuiPaneInfo().
+                              Name(name).Caption(_("Map Toolbar")).
+                              ToolbarPane().Top().
+                              LeftDockable(False).RightDockable(False).
+                              BottomDockable(False).TopDockable(True).
+                              CloseButton(False).Layer(2).Row(1).
+                              BestSize((self.toolbars[name].GetBestSize())))
 
         if name == "swipeMain":
             self.toolbars[name] = SwipeMainToolbar(self)
 
             self._mgr.AddPane(self.toolbars[name],
-                      wx.aui.AuiPaneInfo().
-                      Name(name).Caption(_("Main Toolbar")).
-                      ToolbarPane().Top().
-                      LeftDockable(False).RightDockable(False).
-                      BottomDockable(False).TopDockable(True).
-                      CloseButton(False).Layer(2).Row(1).
-                      BestSize((self.toolbars[name].GetBestSize())))
+                              wx.aui.AuiPaneInfo().
+                              Name(name).Caption(_("Main Toolbar")).
+                              ToolbarPane().Top().
+                              LeftDockable(False).RightDockable(False).
+                              BottomDockable(False).TopDockable(True).
+                              CloseButton(False).Layer(2).Row(1).
+                              BestSize((self.toolbars[name].GetBestSize())))
 
         if name == "swipeMisc":
             self.toolbars[name] = SwipeMiscToolbar(self)
 
             self._mgr.AddPane(self.toolbars[name],
-                      wx.aui.AuiPaneInfo().
-                      Name(name).Caption(_("Misc Toolbar")).
-                      ToolbarPane().Top().
-                      LeftDockable(False).RightDockable(False).
-                      BottomDockable(False).TopDockable(True).
-                      CloseButton(False).Layer(2).Row(1).
-                      BestSize((self.toolbars[name].GetBestSize())))
+                              wx.aui.AuiPaneInfo().
+                              Name(name).Caption(_("Misc Toolbar")).
+                              ToolbarPane().Top().
+                              LeftDockable(False).RightDockable(False).
+                              BottomDockable(False).TopDockable(True).
+                              CloseButton(False).Layer(2).Row(1).
+                              BestSize((self.toolbars[name].GetBestSize())))
 
     def _addPanes(self):
         """Add splitter window and sliders to aui manager"""
         # splitter window
         self._mgr.AddPane(self.splitter, wx.aui.AuiPaneInfo().
-                  Name('splitter').CaptionVisible(False).PaneBorder(True).
-                  Dockable(False).Floatable(False).CloseButton(False).
-                  Center().Layer(1).BestSize((self.splitter.GetBestSize())))
+                          Name('splitter').CaptionVisible(False).PaneBorder(True).
+                          Dockable(False).Floatable(False).CloseButton(False).
+                          Center().Layer(1).BestSize((self.splitter.GetBestSize())))
 
         # sliders
         self._mgr.AddPane(self.sliderH, wx.aui.AuiPaneInfo().
-                  Name('sliderH').CaptionVisible(False).PaneBorder(False).
-                  CloseButton(False).Gripper(True).GripperTop(False).
-                  BottomDockable(True).TopDockable(True).
-                  LeftDockable(False).RightDockable(False).
-                  Bottom().Layer(1).BestSize((self.sliderH.GetBestSize())))
+                          Name('sliderH').CaptionVisible(False).PaneBorder(False).
+                          CloseButton(False).Gripper(True).GripperTop(False).
+                          BottomDockable(True).TopDockable(True).
+                          LeftDockable(False).RightDockable(False).
+                          Bottom().Layer(1).BestSize((self.sliderH.GetBestSize())))
 
         self._mgr.AddPane(self.sliderV, wx.aui.AuiPaneInfo().
-                  Name('sliderV').CaptionVisible(False).PaneBorder(False).
-                  CloseButton(False).Gripper(True).GripperTop(True).
-                  BottomDockable(False).TopDockable(False).
-                  LeftDockable(True).RightDockable(True).
-                  Right().Layer(1).BestSize((self.sliderV.GetBestSize())))
+                          Name('sliderV').CaptionVisible(False).PaneBorder(False).
+                          CloseButton(False).Gripper(True).GripperTop(True).
+                          BottomDockable(False).TopDockable(False).
+                          LeftDockable(True).RightDockable(True).
+                          Right().Layer(1).BestSize((self.sliderV.GetBestSize())))
 
     def ZoomToMap(self):
         """
@@ -357,11 +373,12 @@ class SwipeMapFrame(DoubleMapFrame):
                                  firstLayerList=None, secondLayerList=None)
             dlg.applyChanges.connect(self.OnApplyInputChanges)
             # connect to convertor object to convert to Map
-            # store reference to convertor is needed otherwise it would be discarded
-            self._firstConverter = self._connectSimpleLmgr(dlg.GetFirstSimpleLmgr(),
-                                                           self.GetFirstMap())
-            self._secondConverter = self._connectSimpleLmgr(dlg.GetSecondSimpleLmgr(),
-                                                            self.GetSecondMap())
+            # store reference to convertor is needed otherwise it would be
+            # discarded
+            self._firstConverter = self._connectSimpleLmgr(
+                dlg.GetFirstSimpleLmgr(), self.GetFirstMap())
+            self._secondConverter = self._connectSimpleLmgr(
+                dlg.GetSecondSimpleLmgr(), self.GetSecondMap())
             self._inputDialog = dlg
             dlg.CentreOnParent()
             dlg.Show()
@@ -397,15 +414,18 @@ class SwipeMapFrame(DoubleMapFrame):
             if not (res1 and res2) and first and second:
                 message = ''
                 if not res1:
-                    message += _("Map <%s> not found. ") % self.rasters['first']
+                    message += _("Map <%s> not found. ") % self.rasters[
+                        'first']
                 if not res2:
-                    message += _("Map <%s> not found.") % self.rasters['second']
-                    GError(parent = self, message = message)
+                    message += _("Map <%s> not found.") % self.rasters[
+                        'second']
+                    GError(parent=self, message=message)
                     return
             self.ZoomToMap()
         else:
             LayerListToRendererConverter(self.GetFirstMap()).ConvertAll(first)
-            LayerListToRendererConverter(self.GetSecondMap()).ConvertAll(second)
+            LayerListToRendererConverter(
+                self.GetSecondMap()).ConvertAll(second)
 
         self.SetRasterNames()
         if self.IsAutoRendered():
@@ -413,38 +433,47 @@ class SwipeMapFrame(DoubleMapFrame):
 
     def SetFirstRaster(self, name):
         """Set raster map to first Map"""
-        raster = grass.find_file(name = name, element = 'cell')
+        raster = grass.find_file(name=name, element='cell')
         if raster['fullname']:
             self.rasters['first'] = raster['fullname']
-            self.SetLayer(name = raster['fullname'], mapInstance = self.GetFirstMap())
+            self.SetLayer(
+                name=raster['fullname'],
+                mapInstance=self.GetFirstMap())
             return True
 
         return False
 
     def SetSecondRaster(self, name):
         """Set raster map to second Map"""
-        raster = grass.find_file(name = name, element = 'cell')
+        raster = grass.find_file(name=name, element='cell')
         if raster['fullname']:
             self.rasters['second'] = raster['fullname']
-            self.SetLayer(name = raster['fullname'], mapInstance = self.GetSecondMap())
+            self.SetLayer(
+                name=raster['fullname'],
+                mapInstance=self.GetSecondMap())
             return True
 
         return False
 
     def SetLayer(self, name, mapInstance):
         """Sets layer in Map.
-        
+
         :param name: layer (raster) name
         """
-        Debug.msg (3, "SwipeMapFrame.SetLayer(): name=%s" % name)
-        
+        Debug.msg(3, "SwipeMapFrame.SetLayer(): name=%s" % name)
+
         # this simple application enables to keep only one raster
         mapInstance.DeleteAllLayers()
         cmdlist = ['d.rast', 'map=%s' % name]
         # add layer to Map instance (core.render)
-        newLayer = mapInstance.AddLayer(ltype = 'raster', command = cmdlist, active = True,
-                                        name = name, hidden = False, opacity = 1.0,
-                                        render = True)
+        newLayer = mapInstance.AddLayer(
+            ltype='raster',
+            command=cmdlist,
+            active=True,
+            name=name,
+            hidden=False,
+            opacity=1.0,
+            render=True)
 
     def OnSwitchWindows(self, event):
         """Switch windows position."""
@@ -517,32 +546,32 @@ class SwipeMapFrame(DoubleMapFrame):
         """
         img = self.firstMapWindow.img or self.secondMapWindow.img
         if not img:
-            GMessage(parent = self,
-                     message = _("Nothing to render (empty map). Operation canceled."))
+            GMessage(parent=self, message=_(
+                "Nothing to render (empty map). Operation canceled."))
             return
         filetype, ltype = GetImageHandlers(img)
-        
+
         # get filename
-        dlg = wx.FileDialog(parent = self,
-                            message = _("Choose a file name to save the image "
-                                        "(no need to add extension)"),
-                            wildcard = filetype,
-                            style = wx.FD_SAVE | wx.FD_OVERWRITE_PROMPT)
-        
+        dlg = wx.FileDialog(parent=self,
+                            message=_("Choose a file name to save the image "
+                                      "(no need to add extension)"),
+                            wildcard=filetype,
+                            style=wx.FD_SAVE | wx.FD_OVERWRITE_PROMPT)
+
         if dlg.ShowModal() == wx.ID_OK:
             path = dlg.GetPath()
             if not path:
                 dlg.Destroy()
                 return
-            
+
             base, ext = os.path.splitext(path)
             fileType = ltype[dlg.GetFilterIndex()]['type']
-            extType  = ltype[dlg.GetFilterIndex()]['ext']
+            extType = ltype[dlg.GetFilterIndex()]['ext']
             if ext != extType:
                 path = base + '.' + extType
-            
+
             self._saveToFile(path, fileType)
-            
+
         dlg.Destroy()
 
     def OnSwitchOrientation(self, event):
@@ -552,13 +581,15 @@ class SwipeMapFrame(DoubleMapFrame):
         splitter = self.splitter
         splitter.Unsplit()
         if splitter.GetSplitMode() == wx.SPLIT_HORIZONTAL:
-            splitter.SplitVertically(self.firstMapWindow, self.secondMapWindow, 0)
+            splitter.SplitVertically(
+                self.firstMapWindow, self.secondMapWindow, 0)
             self.slider = self.sliderH
             if self._mode == 'swipe':
                 self._mgr.GetPane('sliderH').Show()
                 self._mgr.GetPane('sliderV').Hide()
         else:
-            splitter.SplitHorizontally(self.firstMapWindow, self.secondMapWindow, 0)
+            splitter.SplitHorizontally(
+                self.firstMapWindow, self.secondMapWindow, 0)
             self.slider = self.sliderV
             if self._mode == 'swipe':
                 self._mgr.GetPane('sliderV').Show()
@@ -607,9 +638,11 @@ class SwipeMapFrame(DoubleMapFrame):
     def SetRasterNames(self):
         if not self._inputDialog or self._inputDialog.IsSimpleMode():
             if self.rasters['first']:
-                self.GetFirstWindow().SetRasterNameText(self.rasters['first'], 101)
+                self.GetFirstWindow().SetRasterNameText(
+                    self.rasters['first'], 101)
             if self.rasters['second']:
-                self.GetSecondWindow().SetRasterNameText(self.rasters['second'], 102)
+                self.GetSecondWindow().SetRasterNameText(
+                    self.rasters['second'], 102)
         else:
             self.GetFirstWindow().SetRasterNameText('', 101)
             self.GetSecondWindow().SetRasterNameText('', 102)
@@ -619,41 +652,66 @@ class SwipeMapFrame(DoubleMapFrame):
 
         :param x,y: coordinates
         """
-        rasters = ([layer.GetName() for layer in
-                    self.GetFirstMap().GetListOfLayers(ltype='raster', active=True)],
-                   [layer.GetName() for layer in
-                    self.GetSecondMap().GetListOfLayers(ltype='raster', active=True)])
-        vectors = ([layer.GetName() for layer in
-                    self.GetFirstMap().GetListOfLayers(ltype='vector', active=True)],
-                   [layer.GetName() for layer in
-                    self.GetSecondMap().GetListOfLayers(ltype='vector', active=True)])
+        rasters = (
+            [layer.GetName()
+             for layer in self.GetFirstMap().GetListOfLayers(
+                 ltype='raster', active=True)],
+            [layer.GetName()
+             for layer in self.GetSecondMap().GetListOfLayers(
+                 ltype='raster', active=True)])
+        vectors = (
+            [layer.GetName()
+             for layer in self.GetFirstMap().GetListOfLayers(
+                 ltype='vector', active=True)],
+            [layer.GetName()
+             for layer in self.GetSecondMap().GetListOfLayers(
+                 ltype='vector', active=True)])
 
         if not (rasters[0] + rasters[1] + vectors[0] + vectors[1]):
-            GMessage(parent=self,
-                     message=_('No raster or vector map layer selected for querying.'))
+            GMessage(
+                parent=self,
+                message=_(
+                    'No raster or vector map layer selected for querying.'))
             return
 
-        # set query snap distance for v.what at map unit equivalent of 10 pixels
-        qdist = 10.0 * ((self.GetFirstMap().region['e'] -
-                         self.GetFirstMap().region['w']) / self.GetFirstMap().width)
+        # set query snap distance for v.what at map unit equivalent of 10
+        # pixels
+        qdist = 10.0 * (
+            (self.GetFirstMap().region['e'] - self.GetFirstMap().region['w']) /
+            self.GetFirstMap().width)
 
         east, north = self.GetFirstWindow().Pixel2Cell((x, y))
 
         # use display region settings instead of computation region settings
         self.tmpreg = os.getenv("GRASS_REGION")
-        os.environ["GRASS_REGION"] = self.GetFirstMap().SetRegion(windres=False)
+        os.environ["GRASS_REGION"] = self.GetFirstMap(
+        ).SetRegion(windres=False)
 
         result = []
         if rasters[0]:
-            result.extend(grass.raster_what(map=rasters[0], coord=(east, north),
-                                            localized=True))
+            result.extend(
+                grass.raster_what(
+                    map=rasters[0],
+                    coord=(east, north),
+                    localized=True))
         if vectors[0]:
-            result.extend(grass.vector_what(map=vectors[0], coord=(east, north), distance=qdist))
+            result.extend(
+                grass.vector_what(
+                    map=vectors[0],
+                    coord=(east, north),
+                    distance=qdist))
         if rasters[1]:
-            result.extend(grass.raster_what(map=rasters[1], coord=(east, north),
-                                            localized=True))
+            result.extend(
+                grass.raster_what(
+                    map=rasters[1],
+                    coord=(east, north),
+                    localized=True))
         if vectors[1]:
-            result.extend(grass.vector_what(map=vectors[1], coord=(east, north), distance=qdist))
+            result.extend(
+                grass.vector_what(
+                    map=vectors[1],
+                    coord=(east, north),
+                    distance=qdist))
 
         self._QueryMapDone()
 
@@ -664,7 +722,8 @@ class SwipeMapFrame(DoubleMapFrame):
         else:
             self._queryDialog = QueryDialog(parent=self, data=result)
             self._queryDialog.Bind(wx.EVT_CLOSE, self._oncloseQueryDialog)
-            self._queryDialog.redirectOutput.connect(lambda output: self._giface.WriteLog(output))
+            self._queryDialog.redirectOutput.connect(
+                lambda output: self._giface.WriteLog(output))
             self._queryDialog.Show()
 
     def _oncloseQueryDialog(self, event):
@@ -694,7 +753,7 @@ class SwipeMapFrame(DoubleMapFrame):
         return True
 
     def OnHelp(self, event):
-        self._giface.Help(entry = 'wxGUI.mapswipe')
+        self._giface.Help(entry='wxGUI.mapswipe')
 
     def OnPreferences(self, event):
         if not self._preferencesDialog:
@@ -712,12 +771,13 @@ class SwipeMapFrame(DoubleMapFrame):
 
 class MapSplitter(wx.SplitterWindow):
     """Splitter window for displaying two maps"""
+
     def __init__(self, parent, id):
-        wx.SplitterWindow.__init__(self, parent = parent, id = id,
-                                   style = wx.SP_LIVE_UPDATE
+        wx.SplitterWindow.__init__(self, parent=parent, id=id,
+                                   style=wx.SP_LIVE_UPDATE
                                    )
         Debug.msg(2, "MapSplitter.__init__()")
-        
+
         self.sashWidthMin = 1
         self.sashWidthMax = 10
         self.Bind(wx.EVT_SPLITTER_SASH_POS_CHANGED, self.OnSashChanged)
@@ -728,7 +788,7 @@ class MapSplitter(wx.SplitterWindow):
         self._moveSash = enable
 
     def Init(self):
-        self.OnSashChanged(evt = None)
+        self.OnSashChanged(evt=None)
         self.SetMinimumPaneSize(0)
         self.SetSashSize(self.sashWidthMin)
 
@@ -763,13 +823,13 @@ class MapSplitter(wx.SplitterWindow):
         w1, w2 = self.GetWindow1(), self.GetWindow2()
         w1.movingSash = False
         w2.movingSash = False
-        
+
         wx.CallAfter(self.SashChanged)
 
     def SashChanged(self):
         Debug.msg(5, "MapSplitter.SashChanged()")
 
-        w1, w2 = self.GetWindow1(), self.GetWindow2() 
+        w1, w2 = self.GetWindow1(), self.GetWindow2()
         w1.SetImageCoords((0, 0))
         if self.GetSplitMode() == wx.SPLIT_VERTICAL:
             w = w1.GetSize()[0]
@@ -778,8 +838,8 @@ class MapSplitter(wx.SplitterWindow):
             h = w1.GetSize()[1]
             w2.SetImageCoords((0, -h))
 
-        w1.UpdateMap(render = False, renderVector = False)
-        w2.UpdateMap(render = False, renderVector = False)
+        w1.UpdateMap(render=False, renderVector=False)
+        w2.UpdateMap(render=False, renderVector=False)
 
         pos = self.GetSashPosition()
         self.last = pos
