@@ -2,6 +2,9 @@
 
 import wx
 
+from grass.script.setup import set_gui_path
+set_gui_path()
+
 from core.gcmd import RunCommand
 from core.utils import _
 from gui_core.preferences import MapsetAccess
@@ -10,15 +13,15 @@ from gui_core.preferences import MapsetAccess
 def main():
     app = wx.App()
 
-    dlg = MapsetAccess(parent = None)
+    dlg = MapsetAccess(parent=None)
     dlg.CenterOnScreen()
 
     if dlg.ShowModal() == wx.ID_OK:
         ms = dlg.GetMapsets()
         RunCommand('g.mapsets',
-                   parent = None,
-                   mapset = '%s' % ','.join(ms),
-                   operation = 'set')
+                   parent=None,
+                   mapset='%s' % ','.join(ms),
+                   operation='set')
 
     dlg.Destroy()
 
