@@ -178,8 +178,10 @@ class TplotFrame(wx.Frame):
             id=wx.ID_ANY,
             label=_(
                 'Raster temporal '
-                'dataset (strds)'))
-
+                'dataset (strds)\n'
+                'Press ENTER after'
+                ' typing the name or select'
+                ' with the combobox'))
         self.datasetSelectR = gselect.Select(
             parent=self.controlPanelRaster, id=wx.ID_ANY,
             size=globalvar.DIALOG_GSELECT_SIZE, type='strds', multiple=True)
@@ -221,11 +223,9 @@ class TplotFrame(wx.Frame):
             label=_(
                 'Vector temporal '
                 'dataset (stvds)\n'
-                'Press ENTER if you'
-                ' type the name of the'
-                ' stvds instead of'
-                ' selecting with the'
-                ' combobox'))
+                'Press ENTER after'
+                ' typing the name or select'
+                ' with the combobox'))
         self.datasetSelectV = gselect.Select(
             parent=self.controlPanelVector, id=wx.ID_ANY,
             size=globalvar.DIALOG_GSELECT_SIZE, type='stvds', multiple=True)
@@ -384,8 +384,8 @@ class TplotFrame(wx.Frame):
         for cat in cats:
             if str(cat) not in categories:
                 GMessage(message=_("Category {ca} is not on vector map"
-                                   " {ma} and it will be used").format(ma=mapp,
-                                                                       ca=cat),
+                                   " {ma} and it will be not used").format(ma=mapp,
+                                                                           ca=cat),
                          parent=self)
                 cats.remove(cat)
         return cats
