@@ -1108,6 +1108,10 @@ class DisplayDriver:
 
         if units is None:
             units = UserSettings.Get(group='vdigit', key=type, subkey='unit')
+            if units is None:
+                # old for backwards comp.
+                units = UserSettings.Get(group='vdigit', key=type, subkey='units')
+                units = 0 if units == 'screen pixels' else 1
 
         if value < 0:
             value = (self.region['nsres'] + self.region['ewres']) / 2.0
