@@ -378,6 +378,7 @@ void GeomCond::parse()
     case 22: /* pleiades1a       * enter month,day,hh.ddd,long.,lat. */
     case 23: /* pleiades1b       * enter month,day,hh.ddd,long.,lat. */
     case 24: /* worldview3       * enter month,day,hh.ddd,long.,lat. */
+    case 25: /* sentinel2a       * enter month,day,hh.ddd,long.,lat. */
    {
 	cin >> month;
 	cin >> jday;
@@ -448,7 +449,8 @@ void GeomCond::print()
 	string(" spot7 observation           "),
 	string(" pleiades1a observation      "),
 	string(" pleiades1b observation      "),
-	string(" worldview3 observation      ")
+	string(" worldview3 observation      "),
+	string(" sentinel2a observation      ")
 	};
 
     static const string head(" geometrical conditions identity  ");
