@@ -12,16 +12,6 @@ int open_files(void)
     int n, missing;
 
     I_init_group_ref(&ref);
-
-    G_strip(group);
-    if (!I_find_group(group))
-	G_fatal_error(_("Group <%s> not found in current mapset"), group);
-
-    G_strip(subgroup);
-    if (!I_find_subgroup(group, subgroup))
-	G_fatal_error(_("Subgroup <%s> in group <%s> not found"),
-		      subgroup, group);
-
     I_free_group_ref(&ref);
     I_get_subgroup_ref(group, subgroup, &ref);
 
