@@ -215,6 +215,10 @@ static int add_or_update_group(char group[INAME_LEN], char **rasters, int k)
 
     for (m = 0; m < k; m++) {
 	skip = 0;
+        if (!rasters[m]) {
+            G_warning(_("No input raster maps defined"));
+            return 0;
+        }
 	if ((mapset = G_find_raster(rasters[m], "")) == NULL) {
 	    G_warning(_("Raster map <%s> not found. Skipped."), rasters[m]);
             skip = 1;
