@@ -1,9 +1,9 @@
 /* Pixel adjacent to cloud unsigned int bits[13]
- * 0 -> class 0: Yes
- * 1 -> class 1: No
+ * 0 -> class 0: No
+ * 1 -> class 1: Yes
  */  
 
-#include <grass/gis.h>
+#include <grass/raster.h>
 
 CELL mod09A1si(CELL pixel) 
 {
