@@ -13,13 +13,12 @@ static int manage_memory(int, int, struct globals *);
 
 int open_files(struct globals *globals)
 {
-    struct Ref Ref;		/* group reference list */
     int *in_fd, bounds_fd, is_null;
     int n, row, col, srows, scols, inlen, outlen, nseg;
     DCELL **inbuf;		/* buffers to store lines from each of the imagery group rasters */
     CELL *boundsbuf, bounds_val;
     int have_bounds = 0;
-    CELL s, id;
+    CELL id;
     struct Range range;	/* min/max values of bounds map */
     struct FPRange *fp_range;	/* min/max values of each input raster */
     DCELL *min, *max;
@@ -36,38 +35,41 @@ int open_files(struct globals *globals)
 
     /* ****** open the input rasters ******* */
 
-    if (!I_get_group_ref(globals->image_group, &Ref))
+    if (!I_get_group_ref(globals->image_group, &globals->Ref))
 	G_fatal_error(_("Group <%s> not found in the current mapset"),
 		      globals->image_group);
 
-    if (Ref.nfiles <= 0)
+    if (globals->Ref.nfiles <= 0)
 	G_fatal_error(_("Group <%s> contains no raster maps"),
 		      globals->image_group);
 
     /* Read Imagery Group */
 
-    in_fd = G_malloc(Ref.nfiles * sizeof(int));
-    inbuf = (DCELL **) G_malloc(Ref.nfiles * sizeof(DCELL *));
-    fp_range = G_malloc(Ref.nfiles * sizeof(struct FPRange));
-    min = G_malloc(Ref.nfiles * sizeof(DCELL));
-    max = G_malloc(Ref.nfiles * sizeof(DCELL));
+    in_fd = G_malloc(globals->Ref.nfiles * sizeof(int));
+    inbuf = (DCELL **) G_malloc(globals->Ref.nfiles * sizeof(DCELL *));
+    fp_range = G_malloc(globals->Ref.nfiles * sizeof(struct FPRange));
+    min = G_malloc(globals->Ref.nfiles * sizeof(DCELL));
+    max = G_malloc(globals->Ref.nfiles * sizeof(DCELL));
+    
+    globals->min = min;
+    globals->max = max;
 
     G_debug(1, "Opening input rasters...");
-    for (n = 0; n < Ref.nfiles; n++) {
+    for (n = 0; n < globals->Ref.nfiles; n++) {
 	inbuf[n] = Rast_allocate_d_buf();
-	in_fd[n] = Rast_open_old(Ref.file[n].name, Ref.file[n].mapset);
+	in_fd[n] = Rast_open_old(globals->Ref.file[n].name, globals->Ref.file[n].mapset);
     }
 
     /* Get min/max values of each input raster for scaling */
 
     globals->max_diff = 0.;
-    globals->nbands = Ref.nfiles;
+    globals->nbands = globals->Ref.nfiles;
 
-    for (n = 0; n < Ref.nfiles; n++) {
+    for (n = 0; n < globals->Ref.nfiles; n++) {
 	/* returns -1 on error, 2 on empty range, quitting either way. */
-	if (Rast_read_fp_range(Ref.file[n].name, Ref.file[n].mapset, &fp_range[n]) != 1)
+	if (Rast_read_fp_range(globals->Ref.file[n].name, globals->Ref.file[n].mapset, &fp_range[n]) != 1)
 	    G_fatal_error(_("No min/max found in raster map <%s>"),
-			  Ref.file[n].name);
+			  globals->Ref.file[n].name);
 	Rast_get_fp_range_min_max(&(fp_range[n]), &min[n], &max[n]);
 
 	G_debug(1, "Range for layer %d: min = %f, max = %f",
@@ -75,7 +77,7 @@ int open_files(struct globals *globals)
 	
     }
     if (globals->weighted == FALSE)
-	globals->max_diff = Ref.nfiles;
+	globals->max_diff = globals->Ref.nfiles;
     else {
 	/* max difference with selected similarity method */
 	Ri.mean = max;
@@ -89,21 +91,21 @@ int open_files(struct globals *globals)
 
     /* size of each element to be stored */
 
-    inlen = sizeof(DCELL) * Ref.nfiles;
+    inlen = sizeof(DCELL) * globals->Ref.nfiles;
     outlen = sizeof(CELL);
     G_debug(1, "data element size, in: %d , out: %d ", inlen, outlen);
     globals->datasize = sizeof(double) * globals->nbands;
 
     /* count non-null cells */
-    globals->notnullcells = (long)globals->nrows * globals->ncols;
+    globals->notnullcells = (LARGEINT)globals->nrows * globals->ncols;
     for (row = 0; row < globals->nrows; row++) {
-	for (n = 0; n < Ref.nfiles; n++) {
+	for (n = 0; n < globals->Ref.nfiles; n++) {
 	    Rast_get_d_row(in_fd[n], inbuf[n], row);
 	}
 	for (col = 0; col < globals->ncols; col++) {
 
 	    is_null = 0;	/*Assume there is data */
-	    for (n = 0; n < Ref.nfiles; n++) {
+	    for (n = 0; n < globals->Ref.nfiles; n++) {
 		if (Rast_is_d_null_value(&inbuf[n][col])) {
 		    is_null = 1;
 		}
@@ -114,7 +116,6 @@ int open_files(struct globals *globals)
 	    }
 	}
     }
-    G_verbose_message(_("Non-NULL cells: %ld"), globals->notnullcells);
     if (globals->notnullcells < 2)
 	G_fatal_error(_("Insufficient number of non-NULL cells in current region"));
 
@@ -130,21 +131,31 @@ int open_files(struct globals *globals)
 	 scols, inlen, nseg) != 1)
 	G_fatal_error("Unable to create input temporary files");
 
+    if (globals->method == ORM_MS) {
+	if (Segment_open
+	    (&globals->bands_seg2, G_tempfile(), globals->nrows, globals->ncols, srows,
+	     scols, inlen, nseg) != 1)
+	    G_fatal_error("Unable to create input temporary files");
+	
+	globals->bands_in = &globals->bands_seg;
+	globals->bands_out = &globals->bands_seg2;
+    }
+
     if (Segment_open
 	(&globals->rid_seg, G_tempfile(), globals->nrows, globals->ncols, srows,
 	 scols, outlen, nseg * 2) != 1)
 	G_fatal_error("Unable to create input temporary files");
 
     /* load input bands to segment structure */
-    if (Ref.nfiles > 1)
+    if (globals->Ref.nfiles > 1)
 	G_message(_("Loading input bands..."));
     else
 	G_message(_("Loading input band..."));
 
     globals->bands_val = (double *)G_malloc(inlen);
     globals->second_val = (double *)G_malloc(inlen);
-    /* initial segment ID */
-    s = 1;
+
+    globals->max_rid = 0;
 
     globals->row_min = globals->nrows;
     globals->row_max = 0;
@@ -152,13 +163,13 @@ int open_files(struct globals *globals)
     globals->col_max = 0;
     for (row = 0; row < globals->nrows; row++) {
 	G_percent(row, globals->nrows, 4);
-	for (n = 0; n < Ref.nfiles; n++) {
+	for (n = 0; n < globals->Ref.nfiles; n++) {
 	    Rast_get_d_row(in_fd[n], inbuf[n], row);
 	}
 	for (col = 0; col < globals->ncols; col++) {
 
 	    is_null = 0;	/*Assume there is data */
-	    for (n = 0; n < Ref.nfiles; n++) {
+	    for (n = 0; n < globals->Ref.nfiles; n++) {
 		globals->bands_val[n] = inbuf[n][col];
 		if (Rast_is_d_null_value(&inbuf[n][col])) {
 		    is_null = 1;
@@ -173,13 +184,14 @@ int open_files(struct globals *globals)
 	                    (void *)globals->bands_val, row, col) != 1)
 		G_fatal_error(_("Unable to write to temporary file"));
 
-	    if (!is_null) {
-		if (!globals->seeds) {
-		    /* sequentially number all cells with a unique segment ID */
-		    id = s;
-		    s++;
-		}
+	    if (globals->method == ORM_MS) {
+		if (Segment_put(&globals->bands_seg2,
+				(void *)globals->bands_val, row, col) != 1)
+		    G_fatal_error(_("Unable to write to temporary file"));
+	    }
 
+	    id = 0;
+	    if (!is_null) {
 		/* get min/max row/col to narrow the processing window */
 		if (globals->row_min > row)
 		    globals->row_min = row;
@@ -195,11 +207,9 @@ int open_files(struct globals *globals)
 		Rast_set_c_null_value(&id, 1);
 		FLAG_SET(globals->null_flag, row, col);
 	    }
-	    if (!globals->seeds || is_null) {
-		if (Segment_put(&globals->rid_seg,
-		                (void *)&id, row, col) != 1)
-		    G_fatal_error(_("Unable to write to temporary file"));
-	    }
+	    if (Segment_put(&globals->rid_seg,
+			    (void *)&id, row, col) != 1)
+		G_fatal_error(_("Unable to write to temporary file"));
 	}
     }
     G_percent(1, 1, 1);
@@ -210,7 +220,7 @@ int open_files(struct globals *globals)
     
     globals->row_max++;
     globals->col_max++;
-    globals->ncells = (long)(globals->row_max - globals->row_min) *
+    globals->ncells = (LARGEINT)(globals->row_max - globals->row_min) *
 			    (globals->col_max - globals->col_min);
 
     /* bounds/constraints */
@@ -281,7 +291,7 @@ int open_files(struct globals *globals)
 
     /* Free memory */
 
-    for (n = 0; n < Ref.nfiles; n++) {
+    for (n = 0; n < globals->Ref.nfiles; n++) {
 	G_free(inbuf[n]);
 	Rast_close(in_fd[n]);
     }
@@ -290,19 +300,15 @@ int open_files(struct globals *globals)
     globals->rs.mean = G_malloc(globals->datasize);
 
     globals->reg_tree = rgtree_create(globals->nbands, globals->datasize);
-    globals->n_regions = s - 1;
 
-    if (globals->seeds) {
+    if (globals->method == ORM_RG && globals->seeds) {
 	load_seeds(globals, srows, scols, nseg);
+	G_debug(1, "Number of initial regions: %d", globals->max_rid);
     }
 
-    G_debug(1, "Number of initial regions: %d", globals->n_regions);
-
     G_free(inbuf);
     G_free(in_fd);
     G_free(fp_range);
-    G_free(min);
-    G_free(max);
 
     return TRUE;
 }
@@ -313,12 +319,17 @@ static int load_seeds(struct globals *globals, int srows, int scols, int nseg)
     int row, col;
     SEGMENT seeds_seg;
     CELL *seeds_buf, seeds_val;
-    int seeds_fd;
-    int spos, sneg, have_seeds;
+    int seeds_fd, have_seeds;
+    CELL new_id, cellmax, noid;
     struct rc Ri;
 
     G_debug(1, "load_seeds()");
-    
+
+    cellmax = (1 << (sizeof(CELL) * 8 - 2)) - 1;
+    cellmax += (1 << (sizeof(CELL) * 8 - 2));
+
+    noid = 0;
+
     G_message(_("Loading seeds from raster map <%s>..."), globals->seeds);
 
     if (Segment_open
@@ -356,8 +367,7 @@ static int load_seeds(struct globals *globals, int srows, int scols, int nseg)
 	return 0;
     }
 
-    spos = 1;
-    sneg = -1;
+    new_id = 0;
 
     /* convert seeds to regions */
     G_debug(1, "convert seeds to regions");
@@ -368,17 +378,18 @@ static int load_seeds(struct globals *globals, int srows, int scols, int nseg)
 	    if (!(FLAG_GET(globals->null_flag, row, col)) && 
 	        !(FLAG_GET(globals->candidate_flag, row, col))) {
 
-		if (Rast_is_c_null_value(&(seeds_buf[col]))) {
-		    if (Segment_put(&globals->rid_seg, &sneg, row, col) != 1)
-			G_fatal_error(_("Unable to write to temporary file"));
-		    sneg--;
-		    globals->n_regions--;
-		}
-		else {
+		if (!Rast_is_c_null_value(&(seeds_buf[col]))) {
+		    if (new_id == cellmax)
+			G_fatal_error(_("Too many seeds: integer overflow"));
+
+		    new_id++;
+
 		    Ri.row = row;
 		    Ri.col = col;
-		    read_seed(globals, &seeds_seg, &Ri, spos);
-		    spos++;
+		    if (!read_seed(globals, &seeds_seg, &Ri, new_id)) {
+			new_id--;
+			Segment_put(&globals->rid_seg, (void *)&noid, Ri.row, Ri.col);
+		    }
 		}
 	    }
 	}
@@ -388,7 +399,7 @@ static int load_seeds(struct globals *globals, int srows, int scols, int nseg)
     Rast_close(seeds_fd);
     Segment_close(&seeds_seg);
 
-    globals->n_regions = spos - 1;
+    globals->max_rid = new_id;
     
     flag_clear_all(globals->candidate_flag);
     
@@ -499,9 +510,10 @@ static int read_seed(struct globals *globals, SEGMENT *seeds_seg, struct rc *Ri,
     else {
 	if (globals->rs.count > 1)
 	    update_band_vals(Ri->row, Ri->col, &(globals->rs), globals);
+	else if (globals->rs.count == 1) {
+	    return 0;
+	}
     }
-    if (globals->rs.count > 1)
-	globals->n_regions -= (globals->rs.count - 1);
 
     return 1;
 }
@@ -511,46 +523,64 @@ static int manage_memory(int srows, int scols, struct globals *globals)
 {
     double reg_size_mb, segs_mb;
     int reg_size_count, nseg, nseg_total;
+    
+    segs_mb = globals->mb;
+    if (globals->method == ORM_RG) {
 
-    /* minimum region size to store in search tree */
-    reg_size_mb = 2 * globals->datasize +     /* mean, sum */
-                  2 * sizeof(int) +           /* id, count */
-		  sizeof(unsigned char) + 
-		  2 * sizeof(struct REG_NODE *);
-    reg_size_mb /= (1024. * 1024.);
+	/* minimum region size to store in search tree */
+	reg_size_mb = 2 * globals->datasize +     /* mean, sum */
+		      2 * sizeof(int) +           /* id, count */
+		      sizeof(unsigned char) + 
+		      2 * sizeof(struct REG_NODE *);
+	reg_size_mb /= (1024. * 1024.);
 
-    /* put aside some memory for segment structures */
-    segs_mb = globals->mb * 0.1;
-    if (segs_mb > 10)
-	segs_mb = 10;
+	/* put aside some memory for segment structures */
+	segs_mb = globals->mb * 0.1;
+	if (segs_mb > 10)
+	    segs_mb = 10;
 
-    /* calculate number of region stats that can be kept in memory */
-    reg_size_count = (globals->mb - segs_mb) / reg_size_mb;
-    globals->min_reg_size = 3;
-    if (reg_size_count < (double) globals->notnullcells / globals->min_reg_size) {
-	globals->min_reg_size = (double) globals->notnullcells / reg_size_count;
+	/* calculate number of region stats that can be kept in memory */
+	reg_size_count = (globals->mb - segs_mb) / reg_size_mb;
+	globals->min_reg_size = 3;
+	if (reg_size_count < (double) globals->notnullcells / globals->min_reg_size) {
+	    globals->min_reg_size = (double) globals->notnullcells / reg_size_count;
+	}
+	else {
+	    reg_size_count = (double) globals->notnullcells / globals->min_reg_size;
+	    /* recalculate segs_mb */
+	    segs_mb = globals->mb - reg_size_count * reg_size_mb;
+	}
+
+	G_verbose_message(_("Regions with at least %d cells are stored in memory"),
+			  globals->min_reg_size);
     }
-    else {
-	reg_size_count = (double) globals->notnullcells / globals->min_reg_size;
-	/* recalculate segs_mb */
-	segs_mb = globals->mb - reg_size_count * reg_size_mb;
-    }
-
-    G_verbose_message(_("Regions with at least %d cells are stored in memory"),
-                      globals->min_reg_size);
 
     /* calculate number of segments in memory */
     if (globals->bounds_map != NULL) {
 	/* input bands, segment ids, bounds map */
-	nseg = (1024. * 1024. * segs_mb) /
-	       (sizeof(DCELL) * globals->nbands * srows * scols + 
-		sizeof(CELL) * 4 * srows * scols);
+	if (globals->method == ORM_MS) {
+	    nseg = (1024. * 1024. * segs_mb) /
+		   (sizeof(DCELL) * 2 * globals->nbands * srows * scols + 
+		    sizeof(CELL) * 4 * srows * scols);
+	}
+	else {
+	    nseg = (1024. * 1024. * segs_mb) /
+		   (sizeof(DCELL) * globals->nbands * srows * scols + 
+		    sizeof(CELL) * 4 * srows * scols);
+	}
     }
     else {
 	/* input bands, segment ids */
-	nseg = (1024. * 1024. * segs_mb) /
-	       (sizeof(DCELL) * globals->nbands * srows * scols + 
-		sizeof(CELL) * 2 * srows * scols);
+	if (globals->method == ORM_MS) {
+	    nseg = (1024. * 1024. * segs_mb) /
+		   (sizeof(DCELL) * 2 * globals->nbands * srows * scols + 
+		    sizeof(CELL) * 2 * srows * scols);
+	}
+	else {
+	    nseg = (1024. * 1024. * segs_mb) /
+		   (sizeof(DCELL) * globals->nbands * srows * scols + 
+		    sizeof(CELL) * 2 * srows * scols);
+	}
     }
     nseg_total = (globals->nrows / srows + (globals->nrows % srows > 0)) *
                  (globals->ncols / scols + (globals->ncols % scols > 0));
