@@ -72,9 +72,29 @@
 #define RELDIR "?"
 #endif
 
+/* GDAL < 2.3 does not define HAVE_LONG_LONG when compiled with 
+ * Visual Studio as for OSGeo4W, even though long long is available,
+ * and GIntBig falls back to long which is on Windows always 4 bytes.
+ * This patch ensures that GIntBig is defined as long long (8 bytes)
+ * if GDAL is compiled with Visual Studio and GRASS is compiled with 
+ * MinGW. This patch must be applied before other GDAL/OGR headers are
+ * included, as done by gprojects.h and vector.h */
+#if defined(__MINGW32__) && HAVE_GDAL
+# include <gdal_version.h>
+# if GDAL_VERSION_NUM < 2030000
+#  include <cpl_config.h>
+   /* HAVE_LONG_LONG_INT comes from GRASS
+    * HAVE_LONG_LONG comes from GDAL */
+#  if HAVE_LONG_LONG_INT && !defined(HAVE_LONG_LONG)
+#   define HAVE_LONG_LONG 1
+#  endif
+# endif
+#endif
+
 /* adj_cellhd.c */
 void G_adjust_Cell_head(struct Cell_head *, int, int);
 void G_adjust_Cell_head3(struct Cell_head *, int, int, int);
+int G_adjust_window_ll(struct Cell_head *cellhd);
 
 /* alloc.c */
 #define G_incr_void_ptr(ptr, size) \
