@@ -4,7 +4,7 @@
 #include "local_proto.h"
 
 
-double *chi_square(double *x, int n)
+double *Cdhc_chi_square(double *x, int n)
 {
     static double y[2];
     double mean = 0.0, sdx = 0.0, sum3 = 0.0, *v;
@@ -16,11 +16,11 @@ double *chi_square(double *x, int n)
 	--k;
 
     if ((f = (int *)calloc(k, sizeof(int))) == NULL) {
-	fprintf(stderr, "Memory error in chi_square\n");
+	fprintf(stderr, "Memory error in Cdhc_chi_square\n");
 	exit(EXIT_FAILURE);
     }
     if ((v = (double *)malloc((k + 1) * sizeof(double))) == NULL) {
-	fprintf(stderr, "Memory error in chi_square\n");
+	fprintf(stderr, "Memory error in Cdhc_chi_square\n");
 	exit(EXIT_FAILURE);
     }
 
@@ -33,7 +33,7 @@ double *chi_square(double *x, int n)
 
     v[0] = -1e9;
     for (i = 1; i < k; ++i)
-	v[i] = mean + xinormal((double)i / k) * sdx;
+	v[i] = mean + Cdhc_xinormal((double)i / k) * sdx;
 
     v[k] = 1e9;
 
