@@ -4,12 +4,12 @@
 #include "local_proto.h"
 
 
-double *kolmogorov_smirnov_exp(double *x, int n)
+double *Cdhc_kolmogorov_smirnov_exp(double *x, int n)
 {
     static double y[2];
     double *d, sqrtn;
 
-    d = dmax_exp(x, n);
+    d = Cdhc_dmax_exp(x, n);
     sqrtn = sqrt((double)n);
 
     y[1] = (d[0] > d[1]) ? d[0] : d[1];
