@@ -29,7 +29,7 @@
 #include <grass/gis.h>
 #include <grass/glocale.h>
 
-#include "local_proto.h"
+#include "gis_local_proto.h"
 
 static int G__open_misc(const char *dir,
 			const char *element,
