@@ -1,17 +1,14 @@
-
-/**
- * \file whoami.c
+/*!
+ * \file lib/gis/whoami.c
  *
  * \brief GIS Library - Login name functions.
  *
- * (C) 2001-2008 by the GRASS Development Team
+ * (C) 2001-2009 by the GRASS Development Team
  *
  * This program is free software under the GNU General Public License
  * (>=v2). Read the file COPYING that comes with GRASS for details.
  *
- * \author GRASS GIS Development Team
- *
- * \date 1999-2008
+ * \author Original author CERL
  */
 
 #include <unistd.h>
@@ -23,8 +20,7 @@
 
 #include <grass/gis.h>
 
-
-/**
+/*!
  * \brief Gets user's name.
  *
  * Returns a pointer to a string containing the user's login name.
@@ -34,46 +30,37 @@
  * because the ttyname(0) rotuine fails in ucb universe.
  * So we check for this, too.
  *
- *  \retval char * Pointer to string
+ * \return pointer to string ("anonymous" by default)
  */
-
-char *G_whoami(void)
+const char *G_whoami(void)
 {
+    static int initialized;
+    static const char *name;
+
+    if (G_is_initialized(&initialized))
+	return name;
+
 #ifdef __MINGW32__
-    char *name = getenv("USERNAME");
+    name = getenv("USERNAME");
+#endif
+    if (!name || !*name)
+	name = getenv("LOGNAME");
 
-    if (name == NULL) {
-	name = "user_name";
-    }
-#else
-    static char *name = NULL;
+    if (!name || !*name)
+	name = getenv("USER");
 
-#ifdef COMMENTED_OUT
-    char *getlogin();
-    char *ttyname();
-
-    if (name == NULL) {
-	char *x;
-
-	x = ttyname(0);
-	if (x && *x) {
-	    x = getlogin();
-	    if (x && *x)
-		name = G_store(x);
-	}
-    }
-#endif /* COMMENTED_OUT */
-
-    if (name == NULL) {
-	struct passwd *p;
-
-	if ((p = getpwuid(getuid())))
+#ifndef __MINGW32__
+    if (!name || !*name) {
+	struct passwd *p = getpwuid(getuid());
+	if (p && p->pw_name && *p->pw_name)
 	    name = G_store(p->pw_name);
     }
-    if (name == NULL)
-	name = G_store("?");
-
 #endif
 
+    if (!name || !*name)
+	name = "anonymous";
+
+    G_initialize_done(&initialized);
+
     return name;
 }
