@@ -5,7 +5,7 @@
    \brief GProj Library - Functions for manipulating co-ordinate
    system representations
 
-   (C) 2003-2008, 2012 by the GRASS Development Team
+   (C) 2003-2017 by the GRASS Development Team
  
    This program is free software under the GNU General Public License
    (>=v2). Read the file COPYING that comes with GRASS for details.
@@ -33,34 +33,16 @@
 static void DatumNameMassage(char **);
 #endif
 
-/*!
- * \brief Converts a GRASS co-ordinate system representation to WKT style.
- * 
- * Takes a GRASS co-ordinate system as specified by two sets of
- * key/value pairs derived from the PROJ_INFO and PROJ_UNITS files,
- * and converts it to the 'Well Known Text' format popularised by
- * proprietary GIS
- * 
- * \param proj_info Set of GRASS PROJ_INFO key/value pairs
- * \param proj_units Set of GRASS PROJ_UNIT key/value pairs
- * \param esri_style boolean Output ESRI-style WKT (Use OSRMorphToESRI() 
- *                   function provided by OGR library)
- * \param prettify boolean Use linebreaks and indents to 'prettify' output
- *                 WKT string (Use OSRExportToPrettyWkt() function in OGR)
- *
- * \return Pointer to a string containing the co-ordinate system in
- *         WKT format
- * \return NULL on error
- */
-char *GPJ_grass_to_wkt(const struct Key_Value *proj_info,
-		       const struct Key_Value *proj_units,
-		       int esri_style, int prettify)
+static char *grass_to_wkt(const struct Key_Value *proj_info,
+                          const struct Key_Value *proj_units,
+                          const struct Key_Value *proj_epsg,
+                          int esri_style, int prettify)
 {
 #ifdef HAVE_OGR
     OGRSpatialReferenceH hSRS;
     char *wkt, *local_wkt;
 
-    hSRS = GPJ_grass_to_osr(proj_info, proj_units);
+    hSRS = GPJ_grass_to_osr2(proj_info, proj_units, proj_epsg);
 
     if (hSRS == NULL)
 	return NULL;
@@ -84,6 +66,63 @@ char *GPJ_grass_to_wkt(const struct Key_Value *proj_info,
 #endif
 }
 
+/*!
+ * \brief Converts a GRASS co-ordinate system representation to WKT style.
+ * 
+ * Takes a GRASS co-ordinate system as specified by two sets of
+ * key/value pairs derived from the PROJ_INFO and PROJ_UNITS files,
+ * and converts it to the 'Well Known Text' format.
+ * 
+ * \param proj_info Set of GRASS PROJ_INFO key/value pairs
+ * \param proj_units Set of GRASS PROJ_UNIT key/value pairs
+ * \param esri_style boolean Output ESRI-style WKT (Use OSRMorphToESRI() 
+ *                   function provided by OGR library)
+ * \param prettify boolean Use linebreaks and indents to 'prettify' output
+ *                 WKT string (Use OSRExportToPrettyWkt() function in OGR)
+ *
+ * \return Pointer to a string containing the co-ordinate system in
+ *         WKT format
+ * \return NULL on error
+ */
+char *GPJ_grass_to_wkt(const struct Key_Value *proj_info,
+                       const struct Key_Value *proj_units,
+                       int esri_style, int prettify)
+{
+    return grass_to_wkt(proj_info, proj_units, NULL, esri_style, prettify);
+}
+
+/*!
+ * \brief Converts a GRASS co-ordinate system representation to WKT
+ * style. EPSG code is preferred if available.
+ * 
+ * Takes a GRASS co-ordinate system as specified key/value pairs
+ * derived from the PROJ_EPSG file. TOWGS84 parameter is scanned
+ * from PROJ_INFO file and appended to co-ordinate system definition
+ * imported from EPSG code by GDAL library. PROJ_UNITS file is
+ * ignored. The function converts it to the 'Well Known Text' format.
+ * 
+ * \todo Merge with GPJ_grass_to_wkt() in GRASS 8.
+ *
+ * \param proj_info Set of GRASS PROJ_INFO key/value pairs
+ * \param proj_units Set of GRASS PROJ_UNIT key/value pairs
+ * \param proj_epsg Set of GRASS PROJ_EPSG key/value pairs
+ * \param esri_style boolean Output ESRI-style WKT (Use OSRMorphToESRI() 
+ *                   function provided by OGR library)
+ * \param prettify boolean Use linebreaks and indents to 'prettify' output
+ *                 WKT string (Use OSRExportToPrettyWkt() function in OGR)
+ *
+ * \return Pointer to a string containing the co-ordinate system in
+ *         WKT format
+ * \return NULL on error
+ */
+char *GPJ_grass_to_wkt2(const struct Key_Value *proj_info,
+                       const struct Key_Value *proj_units,
+                       const struct Key_Value *proj_epsg,
+                       int esri_style, int prettify)
+{
+    return grass_to_wkt(proj_info, proj_units, proj_epsg, esri_style, prettify);
+}
+
 #ifdef HAVE_OGR
 /*!
  * \brief Converts a GRASS co-ordinate system to an OGRSpatialReferenceH object.
@@ -259,6 +298,67 @@ OGRSpatialReferenceH GPJ_grass_to_osr(const struct Key_Value * proj_info,
     return hSRS2;
 }
 
+/*!
+ * \brief Converts a GRASS co-ordinate system to an
+ * OGRSpatialReferenceH object. EPSG code is preferred if available.
+ * 
+ * The co-ordinate system definition is imported from EPSG (by GDAL)
+ * definition if available. TOWGS84 parameter is scanned from
+ * PROJ_INFO file and appended to co-ordinate system definition. If
+ * EPSG code is not available, PROJ_INFO file is used as
+ * GPJ_grass_to_osr() does.
+
+ * \todo Merge with GPJ_grass_to_osr() in GRASS 8.
+ *
+ * \param proj_info Set of GRASS PROJ_INFO key/value pairs
+ * \param proj_units Set of GRASS PROJ_UNIT key/value pairs
+ * \param proj_epsg Set of GRASS PROJ_EPSG key/value pairs
+ * 
+ * \return OGRSpatialReferenceH object representing the co-ordinate system
+ *         defined by proj_info and proj_units or NULL if it fails
+ */
+OGRSpatialReferenceH GPJ_grass_to_osr2(const struct Key_Value * proj_info,
+                                       const struct Key_Value * proj_units,
+                                       const struct Key_Value * proj_epsg)
+{
+    int epsgcode = 0;
+    
+    if (proj_epsg) {
+        const char *epsgstr = G_find_key_value("epsg", proj_epsg);
+        if (epsgstr)
+            epsgcode = atoi(epsgstr);
+    }
+
+    if (epsgcode) {
+        const char *towgs84;
+        OGRSpatialReferenceH hSRS;
+        
+        hSRS = OSRNewSpatialReference(NULL);
+
+        OSRImportFromEPSG(hSRS, epsgcode);
+
+        /* take +towgs84 from projinfo file if defined) */
+        towgs84 = G_find_key_value("towgs84", proj_info);
+        if (towgs84) {
+            char **tokens;
+            int i;
+            double df[] = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0};
+            
+            tokens = G_tokenize(towgs84, ",");
+
+            for (i = 0; i < G_number_of_tokens(tokens); i++)
+                df[i] = atof(tokens[i]);
+            G_free_tokens(tokens);
+            
+            OSRSetTOWGS84(hSRS, df[0], df[1], df[2], df[3], df[4], df[5], df[6]);
+        }
+        
+        return hSRS;
+    }
+
+    return GPJ_grass_to_osr(proj_info, proj_units);
+}
+
 /*!
  * \brief Converts an OGRSpatialReferenceH object to a GRASS co-ordinate system.
  * 
@@ -279,7 +379,7 @@ OGRSpatialReferenceH GPJ_grass_to_osr(const struct Key_Value * proj_info,
  *                    been defined
  */
 int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
-		     struct Key_Value **projunits, OGRSpatialReferenceH hSRS,
+		     struct Key_Value **projunits, OGRSpatialReferenceH hSRS1,
 		     int datumtrans)
 {
     struct Key_Value *temp_projinfo;
@@ -288,6 +388,13 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
     const char *pszProjCS = NULL;
     char *datum = NULL;
     struct gpj_datum dstruct;
+    const char *ograttr;
+    OGRSpatialReferenceH hSRS;
+
+    *projinfo = NULL;
+    *projunits = NULL;
+
+    hSRS = hSRS1;
 
     if (hSRS == NULL)
 	goto default_to_xy;
@@ -299,6 +406,64 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
      * to start with... */
     OSRMorphFromESRI(hSRS);
 
+    *projinfo = G_create_key_value();
+
+    /* use proj4 definition from EXTENSION attribute if existing */
+    ograttr = OSRGetAttrValue(hSRS, "EXTENSION", 0);
+    if (ograttr && *ograttr && strcmp(ograttr, "PROJ4") == 0) {
+	ograttr = OSRGetAttrValue(hSRS, "EXTENSION", 1);
+	G_debug(3, "proj4 extension:");
+	G_debug(3, "%s", ograttr);
+	
+	if (ograttr && *ograttr) {
+	    char *proj4ext;
+	    OGRSpatialReferenceH hSRS2;
+
+	    hSRS2 = OSRNewSpatialReference(NULL);
+	    proj4ext = G_store(ograttr);
+
+	    /* test */
+	    if (OSRImportFromProj4(hSRS2, proj4ext) != OGRERR_NONE) {
+		G_warning(_("Updating spatial reference with embedded proj4 definition failed. "
+		            "Proj4 definition: <%s>"), proj4ext);
+		OSRDestroySpatialReference(hSRS2);
+	    }
+	    else {
+		/* use new OGR spatial reference defined with embedded proj4 string */
+		/* TODO: replace warning with important_message once confirmed working */
+		G_warning(_("Updating spatial reference with embedded proj4 definition"));
+
+		/* -------------------------------------------------------------------- */
+		/*      Derive the user name for the coordinate system.                 */
+		/* -------------------------------------------------------------------- */
+		pszProjCS = OSRGetAttrValue(hSRS, "PROJCS", 0);
+		if (!pszProjCS)
+		    pszProjCS = OSRGetAttrValue(hSRS, "GEOGCS", 0);
+
+		if (pszProjCS) {
+		    G_set_key_value("name", pszProjCS, *projinfo);
+		}
+		else if (pszProj) {
+		    char path[4095];
+		    char name[80];
+		    
+		    /* use name of the projection as name for the coordinate system */
+
+		    sprintf(path, "%s/etc/proj/projections", G_gisbase());
+		    if (G_lookup_key_value_from_file(path, pszProj, name, sizeof(name)) >
+			0)
+			G_set_key_value("name", name, *projinfo);
+		    else
+			G_set_key_value("name", pszProj, *projinfo);
+		}
+
+		/* the original hSRS1 is left as is, ok? */
+		hSRS = hSRS2;
+	    }
+	    G_free(proj4ext);
+	}
+    }
+
     /* -------------------------------------------------------------------- */
     /*      Set cellhd for well known coordinate systems.                   */
     /* -------------------------------------------------------------------- */
@@ -374,6 +539,11 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
 	    pszProj = pszValue;
 	}
 
+	/* discard @null nadgrids */
+	if (G_strcasecmp(pszToken, "nadgrids") == 0 &&
+	    G_strcasecmp(pszValue, "@null") == 0)
+	    continue;
+
 	/* Ellipsoid and datum handled separately below */
 	if (G_strcasecmp(pszToken, "ellps") == 0
 	    || G_strcasecmp(pszToken, "a") == 0
@@ -393,32 +563,31 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
     if (!pszProj)
 	G_warning(_("No projection name! Projection parameters likely to be meaningless."));
 
-    *projinfo = G_create_key_value();
-
     /* -------------------------------------------------------------------- */
     /*      Derive the user name for the coordinate system.                 */
     /* -------------------------------------------------------------------- */
-    pszProjCS = OSRGetAttrValue(hSRS, "PROJCS", 0);
-    if (!pszProjCS)
-	pszProjCS = OSRGetAttrValue(hSRS, "GEOGCS", 0);
+    if (!G_find_key_value("name", *projinfo)) {
+	pszProjCS = OSRGetAttrValue(hSRS, "PROJCS", 0);
+	if (!pszProjCS)
+	    pszProjCS = OSRGetAttrValue(hSRS, "GEOGCS", 0);
 
-    if (pszProjCS) {
-	G_set_key_value("name", pszProjCS, *projinfo);
+	if (pszProjCS) {
+	    G_set_key_value("name", pszProjCS, *projinfo);
+	}
+	else if (pszProj) {
+	    char path[4095];
+	    char name[80];
+	    
+	    /* use name of the projection as name for the coordinate system */
+
+	    sprintf(path, "%s/etc/proj/projections", G_gisbase());
+	    if (G_lookup_key_value_from_file(path, pszProj, name, sizeof(name)) >
+		0)
+		G_set_key_value("name", name, *projinfo);
+	    else
+		G_set_key_value("name", pszProj, *projinfo);
+	}
     }
-    else if (pszProj) {
-	char path[4095];
-	char name[80];
-	
-	/* use name of the projection as name for the coordinate system */
-
-	sprintf(path, "%s/etc/proj/projections", G_gisbase());
-	if (G_lookup_key_value_from_file(path, pszProj, name, sizeof(name)) >
-	    0)
-	    G_set_key_value("name", name, *projinfo);
-	else
-	    G_set_key_value("name", pszProj, *projinfo);
-    }
-
 
     /* -------------------------------------------------------------------- */
     /*      Find the GRASS datum name and choose parameters either          */
@@ -481,18 +650,18 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
 		    }
 
 		    if (paramsets > 0) {
-			struct gpj_datum_transform_list *list, *old;
+			struct gpj_datum_transform_list *tlist, *old;
 
-			list = GPJ_get_datum_transform_by_name(datum);
+			tlist = GPJ_get_datum_transform_by_name(datum);
 
-			if (list != NULL) {
+			if (tlist != NULL) {
 			    do {
-				if (list->count == datumtrans)
-				    chosenparams = G_store(list->params);
-				old = list;
-				list = list->next;
+				if (tlist->count == datumtrans)
+				    chosenparams = G_store(tlist->params);
+				old = tlist;
+				tlist = tlist->next;
 				GPJ_free_datum_transform(old);
-			    } while (list != NULL);
+			    } while (tlist != NULL);
 			}
 		    }
 
@@ -553,8 +722,10 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
 		 * accept first one that matches. These numbers were found
 		 * by trial and error and could be fine-tuned, or possibly
 		 * a direct comparison of IEEE floating point values used. */
-		if ((a == list->a || fabs(a - list->a) < 0.1 || fabs(1 - a / list->a) < 0.0000001) && ((es == 0 && list->es == 0) ||	/* Special case for sphere */
-												       (invflat == list->rf || fabs(invflat - list->rf) < 0.0000001))) {
+		if ((a == list->a || fabs(a - list->a) < 0.1 || fabs(1 - a / list->a) < 0.0000001) &&
+		    ((es == 0 && list->es == 0) ||
+		    /* Special case for sphere */
+		    (invflat == list->rf || fabs(invflat - list->rf) < 0.0000001))) {
 		    ellps = G_store(list->name);
 		    break;
 		}
@@ -660,6 +831,9 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
 
     }
 
+    if (hSRS != hSRS1)
+	OSRDestroySpatialReference(hSRS);
+
     return 2;
 
     /* -------------------------------------------------------------------- */
@@ -670,10 +844,15 @@ int GPJ_osr_to_grass(struct Cell_head *cellhd, struct Key_Value **projinfo,
 	cellhd->proj = PROJECTION_XY;
 	cellhd->zone = 0;
     }
+    if (*projinfo)
+	G_free_key_value(*projinfo);
 
     *projinfo = NULL;
     *projunits = NULL;
 
+    if (hSRS != hSRS1)
+	OSRDestroySpatialReference(hSRS);
+
     return 1;
 }
 #endif
