@@ -8,9 +8,11 @@ would be a pain. So this module exists to provide a "default" options object
 for convenience.
 """
 
-import optparse, copy
+import copy
+import optparse
 
-default_values={
+
+default_values = {
     "other_headers": [],
     "modules": [],
     "include_search_paths": [],
@@ -33,5 +35,6 @@ default_values={
     "strip_build_path": None
 }
 
+
 def get_default_options():
     return optparse.Values(copy.deepcopy(default_values))
