@@ -14,11 +14,12 @@ for more information.
 
 """
 
-from datacollectingparser import DataCollectingParser
+from .datacollectingparser import DataCollectingParser
+
 
 def parse(headers, options):
-    parser=DataCollectingParser(headers, options)
+    parser = DataCollectingParser(headers, options)
     parser.parse()
     return parser.data()
 
-__all__ = ["parse"]
\ No newline at end of file
+__all__ = ["parse"]
