@@ -5,6 +5,6 @@ This module is the backend to ctypesgen; it contains classes to
 produce the final .py output files.
 """
 
-from printer import WrapperPrinter
+from .printer import WrapperPrinter
 
-__all__ = ["WrapperPrinter"]
\ No newline at end of file
+__all__ = ["WrapperPrinter"]
