@@ -56,7 +56,7 @@ This code is based on gifmaker (in the scripts folder of the source
 distribution of PIL)
 
 
-Usefull links:
+Useful links:
 
   * http://tronche.com/computer-graphics/gif/
   * http://en.wikipedia.org/wiki/Graphics_Interchange_Format
@@ -145,7 +145,7 @@ def checkImages(images):
 
 def intToBin(i):
     """Integer to two bytes"""
-    # devide in two parts (bytes)
+    # divide in two parts (bytes)
     i1 = i % 256
     i2 = int(i / 256)
     # make string (little endian)
@@ -197,7 +197,7 @@ class GifWriter:
         # reserved00, lct size111=7=2^(7 + 1)=256.
         bb += '\x87'
 
-        # LZW min size code now comes later, begining of [image data] blocks
+        # LZW min size code now comes later, beginning of [image data] blocks
         return bb
 
     def getAppExt(self, loops=float('inf')):
@@ -223,7 +223,7 @@ class GifWriter:
 
     def getGraphicsControlExt(self, duration=0.1, dispose=2):
         """Graphics Control Extension. A sort of header at the start of
-        each image. Specifies duration and transparancy.
+        each image. Specifies duration and transparency.
 
         Dispose:
 
@@ -245,7 +245,7 @@ class GifWriter:
         # 2nd bit 1 == user input , next 3 bits, the low two of which are used,
         # are dispose.
         bb += intToBin(int(duration * 100))  # in 100th of seconds
-        bb += '\x00'  # no transparant color
+        bb += '\x00'  # no transparent color
         bb += '\x00'  # end
         return bb
 
@@ -334,8 +334,8 @@ class GifWriter:
             Y = np.argwhere(diff.sum(1))
             # Get rect coordinates
             if X.size and Y.size:
-                x0, x1 = X[0], X[-1] + 1
-                y0, y1 = Y[0], Y[-1] + 1
+                x0, x1 = int(X[0]), int(X[-1] + 1)
+                y0, y1 = int(Y[0]), int(Y[-1] + 1)
             else:  # No change ... make it minimal
                 x0, x1 = 0, 2
                 y0, y1 = 0, 2
@@ -406,7 +406,7 @@ class GifWriter:
 
         """
 
-        # Obtain palette for all images and count each occurance
+        # Obtain palette for all images and count each occurrence
         palettes, occur = [], []
         for im in images:
             if not pillow:
@@ -477,9 +477,56 @@ class GifWriter:
         return frames
 
 
-def writeGif(filename, images, duration=0.1, repeat=True, dither=False,
-             nq=0, subRectangles=True, dispose=None):
+def writeGif(filename, images, duration=0.1, repeat=True, **kwargs):
     """Write an animated gif from the specified images.
+    Depending on which PIL library is used, either writeGifVisvis or writeGifPillow
+    is used here.
+
+    :param str filename: the name of the file to write the image to.
+    :param list images: should be a list consisting of PIL images or numpy
+                        arrays. The latter should be between 0 and 255 for
+                        integer types, and between 0 and 1 for float types.
+    :param duration: scalar or list of scalars The duration for all frames, or
+                     (if a list) for each frame.
+    :param repeat: bool or integer The amount of loops. If True, loops infinitetel
+    :param kwargs: additional parameters for writeGifVisvis
+
+    """
+    if pillow:
+        # Pillow >= 3.4.0 has animated GIF writing
+        version = [int(i) for i in PILLOW_VERSION.split('.')]
+        if version[0] > 3 or (version[0] == 3 and version[1] >= 4):
+            writeGifPillow(filename, images, duration, repeat)
+            return
+    # otherwise use the old one
+    writeGifVisvis(filename, images, duration, repeat, **kwargs)
+
+
+def writeGifPillow(filename, images, duration=0.1, repeat=True):
+    """Write an animated gif from the specified images.
+    Uses native Pillow implementation, which is available since Pillow 3.4.0.
+
+    :param str filename: the name of the file to write the image to.
+    :param list images: should be a list consisting of PIL images or numpy
+                        arrays. The latter should be between 0 and 255 for
+                        integer types, and between 0 and 1 for float types.
+    :param duration: scalar or list of scalars The duration for all frames, or
+                     (if a list) for each frame.
+    :param repeat: bool or integer The amount of loops. If True, loops infinitetel
+
+    """
+    loop = 0 if repeat else 1
+    quantized = []
+    for im in images:
+        quantized.append(im.quantize())
+    quantized[0].save(filename, save_all=True, append_images=quantized[1:], loop=loop, duration=duration * 1000)
+
+
+def writeGifVisvis(filename, images, duration=0.1, repeat=True, dither=False,
+                   nq=0, subRectangles=True, dispose=None):
+    """Write an animated gif from the specified images.
+    Uses VisVis implementation. Unfortunately it produces corrupted GIF
+    with Pillow >= 3.4.0.
 
     :param str filename: the name of the file to write the image to.
     :param list images: should be a list consisting of PIL images or numpy
@@ -1013,7 +1060,7 @@ class NeuQuant:
         return Image.fromarray(px).convert("RGB").quantize(palette=self.paletteImage())
 
     def quantize_without_scipy(self, image):
-        """" This function can be used if no scipy is availabe.
+        """" This function can be used if no scipy is available.
         It's 7 times slower though.
 
         :param image:
