@@ -70,20 +70,22 @@ def copy_mapset(mapset, path):
     :returns: the instance of the new Mapset.
 
 
+    >>> from grass.script.core import gisenv
+    >>> mname = gisenv()['MAPSET']
     >>> mset = Mapset()
-    >>> mset.name
-    'user1'
+    >>> mset.name == mname
+    True
     >>> import tempfile as tmp
     >>> import os
     >>> path = os.path.join(tmp.gettempdir(), 'my_loc', 'my_mset')
-    >>> copy_mapset(mset, path)
-    Mapset('user1')
-    >>> sorted(os.listdir(path))
-    [u'PERMANENT', u'user1']
+    >>> copy_mapset(mset, path)                           # doctest: +ELLIPSIS
+    Mapset(...)
+    >>> sorted(os.listdir(path))                          # doctest: +ELLIPSIS
+    [...'PERMANENT'...]
     >>> sorted(os.listdir(os.path.join(path, 'PERMANENT')))
     [u'DEFAULT_WIND', u'PROJ_EPSG', u'PROJ_INFO', u'PROJ_UNITS', u'VAR', u'WIND']
-    >>> sorted(os.listdir(os.path.join(path, 'user1'))) # doctest: +ELLIPSIS
-    [...u'SEARCH_PATH', u'VAR', u'WIND']
+    >>> sorted(os.listdir(os.path.join(path, mname)))   # doctest: +ELLIPSIS
+    [...u'SEARCH_PATH',...u'WIND']
     >>> import shutil
     >>> shutil.rmtree(path)
 
@@ -111,8 +113,12 @@ def read_gisrc(gisrc):
     :returns: a tuple with the mapset, location and gisdbase
 
     >>> import os
-    >>> read_gisrc(os.environ['GISRC'])  # doctest: +ELLIPSIS
-    (u'user1', ...)
+    >>> from grass.script.core import gisenv
+    >>> genv = gisenv()
+    >>> (read_gisrc(os.environ['GISRC']) == (genv['MAPSET'],
+    ...                                      genv['LOCATION_NAME'],
+    ...                                      genv['GISDBASE']))
+    True
     """
     with open(gisrc, 'r') as gfile:
         gis = dict([(k.strip(), v.strip())
@@ -173,7 +179,7 @@ def copy_groups(groups, gisrc_src, gisrc_dst, region=None):
     dst = read_gisrc(gisrc_dst)
     rm = True if src[2] != dst[2] else False
     all_rasts = [r[0]
-                 for r in findmaps('rast', location=dst[1], gisdbase=dst[2])]
+                 for r in findmaps('raster', location=dst[1], gisdbase=dst[2])]
     for grp in groups:
         # change gisdbase to src
         env['GISRC'] = gisrc_src
@@ -334,7 +340,7 @@ def cmd_exe(args):
     - bbox (dict): a dict with the region parameters (n, s, e, w, etc.)
       that we want to set before to apply the command.
     - mapnames (dict): a dictionary to substitute the input if the domain has
-      been splitted in several tiles.
+      been split in several tiles.
     - gisrc_src (str): path of the GISRC file from where we want to copy the
       groups.
     - gisrc_dst (str): path of the GISRC file where the groups will be created.
