@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 Useful functions to be used in Python scripts.
 
@@ -24,6 +25,11 @@ import locale
 import shlex
 import re
 
+
+if sys.version_info.major == 3:
+    unicode = str
+
+
 def float_or_dms(s):
     """Convert DMS to float.
 
@@ -150,17 +156,36 @@ class KeyValue(dict):
         self[key] = value
 
 
+def _get_encoding():
+    encoding = locale.getdefaultlocale()[1]
+    if not encoding:
+        encoding = 'UTF-8'
+    return encoding
+
+
 def decode(bytes_):
     """Decode bytes with default locale and return (unicode) string
 
     No-op if parameter is not bytes (assumed unicode string).
 
     :param bytes bytes_: the bytes to decode
+
+    Example
+    -------
+
+    >>> decode(b'S\xc3\xbcdtirol')
+    u'Südtirol'
+    >>> decode(u'Südtirol')
+    u'Südtirol'
+    >>> decode(1234)
+    u'1234'
     """
+    if isinstance(bytes_, unicode):
+        return bytes_
     if isinstance(bytes_, bytes):
-        enc = locale.getdefaultlocale()[1]
-        return bytes_.decode(enc) if enc else bytes_.decode()
-    return bytes_
+        enc = _get_encoding()
+        return bytes_.decode(enc)
+    return unicode(bytes_)
 
 
 def encode(string):
@@ -170,11 +195,23 @@ def encode(string):
     This ensures garbage in, garbage out.
 
     :param str string: the string to encode
+
+    Example
+    -------
+
+    >>> encode(b'S\xc3\xbcdtirol')
+    b'S\xc3\xbcdtirol'
+    >>> decode(u'Südtirol')
+    b'S\xc3\xbcdtirol'
+    >>> decode(1234)
+    b'1234'
     """
     if isinstance(string, bytes):
         return string
-    enc = locale.getdefaultlocale()[1]
-    return string.encode(enc) if enc else string.encode()
+    if isinstance(string, unicode):
+        enc = _get_encoding()
+        return string.encode(enc)
+    return bytes(string)
 
 
 def parse_key_val(s, sep='=', dflt=None, val_type=None, vsep=None):
