@@ -8,12 +8,16 @@ for details.
 
 :authors: Soeren Gebbert
 """
-
-from .space_time_datasets import *
-from .open_stds import *
+# i18N
+import gettext
+import copy
+from datetime import datetime
 from multiprocessing import Process
 import grass.script as gscript
 from grass.exceptions import CalledModuleError
+from .core import SQLDatabaseInterfaceConnection, get_current_mapset, get_tgis_message_interface
+from .open_stds import open_new_stds, open_old_stds, check_new_stds
+from .datetime_math import time_delta_to_relative_time
 
 ############################################################################
 
@@ -315,6 +319,9 @@ def dataset_mapcalculator(inputs, output, type, expression, base, method,
 
         # Remove empty maps
         if len(empty_maps) > 0:
+            n_empty, n_tot = len(empty_maps), len(map_list)
+            msgr.warning(_("Removing {}/{} ({}%) maps because empty..."
+                           ).format(n_empty, n_tot, n_empty * 100. / n_tot))
             names = ""
             count = 0
             for map in empty_maps:
