@@ -22,7 +22,10 @@ for details.
 :authors: Soeren Gebbert
 """
 from __future__ import print_function
-from .base import *
+# i18N
+import gettext
+from .base import SQLDatabaseInterface
+from .core import init
 
 ###############################################################################
 
