@@ -17,7 +17,11 @@ for details.
 :authors: Soeren Gebbert
 """
 from __future__ import print_function
-from .factory import *
+# i18N
+import gettext
+from .core import get_current_mapset, get_tgis_message_interface, SQLDatabaseInterfaceConnection
+from .datetime_math import time_delta_to_relative_time
+from .factory import dataset_factory
 
 
 def sample_stds_by_stds_topology(intype, sampletype, inputs, sampler, header,
