@@ -15,8 +15,6 @@
 #include <unistd.h>
 #include <sys/types.h>
 
-#include <rpc/types.h>		/* need this for sgi */
-
 #include <grass/config.h>
 #include <grass/raster.h>
 #include <grass/glocale.h>
@@ -137,10 +135,10 @@ static void read_data_compressed(int fd, int row, unsigned char *data_buf,
 	G_fatal_error(_("Error reading raster data for row %d of <%s>"),
 		      row, fcb->name);
 
-    cmp = G_alloca(readamount);
+    cmp = G_malloc(readamount);
 
     if (read(fcb->data_fd, cmp, readamount) != readamount) {
-	G_freea(cmp);
+	G_free(cmp);
 	G_fatal_error(_("Error reading raster data for row %d of <%s>"),
 		      row, fcb->name);
     }
@@ -172,7 +170,7 @@ static void read_data_compressed(int fd, int row, unsigned char *data_buf,
     else
 	memcpy(data_buf, cmp, readamount);
 
-    G_freea(cmp2);
+    G_free(cmp2);
 }
 
 static void read_data_uncompressed(int fd, int row, unsigned char *data_buf,
@@ -205,7 +203,7 @@ static void read_data_gdal(int fd, int row, unsigned char *data_buf,
     if (fcb->gdal->vflip)
 	row = fcb->cellhd.rows - 1 - row;
 
-    buf = fcb->gdal->hflip ? G_alloca(fcb->cellhd.cols * fcb->cur_nbytes)
+    buf = fcb->gdal->hflip ? G_malloc(fcb->cellhd.cols * fcb->cur_nbytes)
 	: data_buf;
 
     err =
@@ -220,7 +218,7 @@ static void read_data_gdal(int fd, int row, unsigned char *data_buf,
 	    memcpy(data_buf + i * fcb->cur_nbytes,
 		   buf + (fcb->cellhd.cols - 1 - i) * fcb->cur_nbytes,
 		   fcb->cur_nbytes);
-	G_freea(buf);
+	G_free(buf);
     }
 
     if (err != CE_None)
@@ -464,7 +462,7 @@ static void transfer_to_cell_XX(int fd, void *cell)
 static void transfer_to_cell_fi(int fd, void *cell)
 {
     struct fileinfo *fcb = &R__.fileinfo[fd];
-    FCELL *work_buf = G_alloca(R__.rd_window.cols * sizeof(FCELL));
+    FCELL *work_buf = G_malloc(R__.rd_window.cols * sizeof(FCELL));
     int i;
 
     transfer_to_cell_XX(fd, work_buf);
@@ -473,13 +471,13 @@ static void transfer_to_cell_fi(int fd, void *cell)
 	((CELL *) cell)[i] = (fcb->col_map[i] == 0)
 	    ? 0 : Rast_quant_get_cell_value(&fcb->quant, work_buf[i]);
 
-    G_freea(work_buf);
+    G_free(work_buf);
 }
 
 static void transfer_to_cell_di(int fd, void *cell)
 {
     struct fileinfo *fcb = &R__.fileinfo[fd];
-    DCELL *work_buf = G_alloca(R__.rd_window.cols * sizeof(DCELL));
+    DCELL *work_buf = G_malloc(R__.rd_window.cols * sizeof(DCELL));
     int i;
 
     transfer_to_cell_XX(fd, work_buf);
@@ -488,12 +486,12 @@ static void transfer_to_cell_di(int fd, void *cell)
 	((CELL *) cell)[i] = (fcb->col_map[i] == 0)
 	    ? 0 : Rast_quant_get_cell_value(&fcb->quant, work_buf[i]);
 
-    G_freea(work_buf);
+    G_free(work_buf);
 }
 
 static void transfer_to_cell_if(int fd, void *cell)
 {
-    CELL *work_buf = G_alloca(R__.rd_window.cols * sizeof(CELL));
+    CELL *work_buf = G_malloc(R__.rd_window.cols * sizeof(CELL));
     int i;
 
     transfer_to_cell_XX(fd, work_buf);
@@ -501,12 +499,12 @@ static void transfer_to_cell_if(int fd, void *cell)
     for (i = 0; i < R__.rd_window.cols; i++)
 	((FCELL *) cell)[i] = work_buf[i];
 
-    G_freea(work_buf);
+    G_free(work_buf);
 }
 
 static void transfer_to_cell_df(int fd, void *cell)
 {
-    DCELL *work_buf = G_alloca(R__.rd_window.cols * sizeof(DCELL));
+    DCELL *work_buf = G_malloc(R__.rd_window.cols * sizeof(DCELL));
     int i;
 
     transfer_to_cell_XX(fd, work_buf);
@@ -514,12 +512,12 @@ static void transfer_to_cell_df(int fd, void *cell)
     for (i = 0; i < R__.rd_window.cols; i++)
 	((FCELL *) cell)[i] = work_buf[i];
 
-    G_freea(work_buf);
+    G_free(work_buf);
 }
 
 static void transfer_to_cell_id(int fd, void *cell)
 {
-    CELL *work_buf = G_alloca(R__.rd_window.cols * sizeof(CELL));
+    CELL *work_buf = G_malloc(R__.rd_window.cols * sizeof(CELL));
     int i;
 
     transfer_to_cell_XX(fd, work_buf);
@@ -527,12 +525,12 @@ static void transfer_to_cell_id(int fd, void *cell)
     for (i = 0; i < R__.rd_window.cols; i++)
 	((DCELL *) cell)[i] = work_buf[i];
 
-    G_freea(work_buf);
+    G_free(work_buf);
 }
 
 static void transfer_to_cell_fd(int fd, void *cell)
 {
-    FCELL *work_buf = G_alloca(R__.rd_window.cols * sizeof(FCELL));
+    FCELL *work_buf = G_malloc(R__.rd_window.cols * sizeof(FCELL));
     int i;
 
     transfer_to_cell_XX(fd, work_buf);
@@ -540,7 +538,7 @@ static void transfer_to_cell_fd(int fd, void *cell)
     for (i = 0; i < R__.rd_window.cols; i++)
 	((DCELL *) cell)[i] = work_buf[i];
 
-    G_freea(work_buf);
+    G_free(work_buf);
 }
 
 /*
@@ -598,7 +596,7 @@ static void get_map_row(int fd, void *rast, int row, RASTER_MAP_TYPE data_type,
     int i;
 
     if (fcb->reclass_flag && data_type != CELL_TYPE) {
-	temp_buf = G_alloca(R__.rd_window.cols * sizeof(CELL));
+	temp_buf = G_malloc(R__.rd_window.cols * sizeof(CELL));
 	buf = temp_buf;
 	type = CELL_TYPE;
     }
@@ -625,7 +623,9 @@ static void get_map_row(int fd, void *rast, int row, RASTER_MAP_TYPE data_type,
 	rast = G_incr_void_ptr(rast, size);
     }
 
-    G_freea(temp_buf);
+    if (fcb->reclass_flag && data_type != CELL_TYPE) {
+	G_free(temp_buf);
+    }
 }
 
 /*!
@@ -835,10 +835,10 @@ static int read_null_bits_compressed(int null_fd, unsigned char *flags,
 	return 1;
     }
 
-    compressed_buf = G_alloca(readamount);
+    compressed_buf = G_malloc(readamount);
 
     if (read(null_fd, compressed_buf, readamount) != readamount) {
-	G_freea(compressed_buf);
+	G_free(compressed_buf);
 	G_fatal_error(_("Error reading null data for row %d of <%s>"),
 		      row, fcb->name);
     }
@@ -849,7 +849,7 @@ static int read_null_bits_compressed(int null_fd, unsigned char *flags,
 		      row, fcb->name);
     }
 
-    G_freea(compressed_buf);
+    G_free(compressed_buf);
 
     return 1;
 }
@@ -907,13 +907,13 @@ static void get_null_value_row_nomask(int fd, char *flags, int row)
 	    fcb->null_cur_row = -1;
 	    if (fcb->map_type == CELL_TYPE) {
 		/* If can't read null row, assume  that all map 0's are nulls */
-		CELL *mask_buf = G_alloca(R__.rd_window.cols * sizeof(CELL));
+		CELL *mask_buf = G_malloc(R__.rd_window.cols * sizeof(CELL));
 
 		get_map_row_nomask(fd, mask_buf, row, CELL_TYPE);
 		for (j = 0; j < R__.rd_window.cols; j++)
 		    flags[j] = (mask_buf[j] == 0);
 
-		G_freea(mask_buf);
+		G_free(mask_buf);
 	    }
 	    else {		/* fp map */
 		/* if can't read null row, assume  that all data is valid */
@@ -969,14 +969,16 @@ static void get_null_value_row_gdal(int fd, char *flags, int row)
 
 static void embed_mask(char *flags, int row)
 {
-    CELL *mask_buf = G_alloca(R__.rd_window.cols * sizeof(CELL));
+    CELL *mask_buf = G_malloc(R__.rd_window.cols * sizeof(CELL));
     int i;
 
-    if (R__.auto_mask <= 0)
+    if (R__.auto_mask <= 0) {
+	G_free(mask_buf);
 	return;
+    }
 
     if (get_map_row_nomask(R__.mask_fd, mask_buf, row, CELL_TYPE) < 0) {
-	G_freea(mask_buf);
+	G_free(mask_buf);
 	return;
     }
 
@@ -989,7 +991,7 @@ static void embed_mask(char *flags, int row)
 	if (mask_buf[i] == 0 || Rast_is_c_null_value(&mask_buf[i]))
 	    flags[i] = 1;
 
-    G_freea(mask_buf);
+    G_free(mask_buf);
 }
 
 static void get_null_value_row(int fd, char *flags, int row, int with_mask)
@@ -1021,7 +1023,7 @@ static void embed_nulls(int fd, void *buf, int row, RASTER_MAP_TYPE map_type,
 	&& (R__.auto_mask <= 0 || !with_mask))
 	return;
 
-    null_buf = G_alloca(R__.rd_window.cols);
+    null_buf = G_malloc(R__.rd_window.cols);
 
     get_null_value_row(fd, null_buf, row, with_mask);
 
@@ -1036,7 +1038,7 @@ static void embed_nulls(int fd, void *buf, int row, RASTER_MAP_TYPE map_type,
 	buf = G_incr_void_ptr(buf, size);
     }
 
-    G_freea(null_buf);
+    G_free(null_buf);
 }
 
 /*!
@@ -1063,13 +1065,13 @@ void Rast_get_null_value_row(int fd, char *flags, int row)
     if (!fcb->reclass_flag)
 	get_null_value_row(fd, flags, row, 1);
     else {
-	CELL *buf = G_alloca(R__.rd_window.cols * sizeof(CELL));
+	CELL *buf = G_malloc(R__.rd_window.cols * sizeof(CELL));
 	int i;
 
 	Rast_get_c_row(fd, buf, row);
 	for (i = 0; i < R__.rd_window.cols; i++)
 	    flags[i] = Rast_is_c_null_value(&buf[i]) ? 1 : 0;
 
-	G_freea(buf);
+	G_free(buf);
     }
 }
