@@ -12,8 +12,6 @@
  * \author USACERL and many others
  */
 
-#include <rpc/types.h>
-#include <rpc/xdr.h>
 #include <unistd.h>
 #include <string.h>
 #include <sys/types.h>
@@ -711,7 +709,7 @@ static int open_raster_new(const char *name, int open_mode,
     fcb->null_row_ptr = NULL;
     if (R__.compress_nulls) {
 	fcb->null_row_ptr = G_calloc(fcb->cellhd.rows + 1, sizeof(off_t));
-	G_zero(fcb->row_ptr, (fcb->cellhd.rows + 1) * sizeof(off_t));
+	G_zero(fcb->null_row_ptr, (fcb->cellhd.rows + 1) * sizeof(off_t));
 	Rast__write_null_row_ptrs(fd, fcb->null_fd);
     }
 
