@@ -1,4 +1,5 @@
 #include <grass/gis.h>
+#include <grass/raster.h>
 
 void c_var(DCELL * result, DCELL * values, int n, const void *closure)
 {
@@ -10,7 +11,7 @@ void c_var(DCELL * result, DCELL * values, int n, const void *closure)
     count = 0;
 
     for (i = 0; i < n; i++) {
-	if (G_is_d_null_value(&values[i]))
+	if (Rast_is_d_null_value(&values[i]))
 	    continue;
 
 	sum += values[i];
@@ -18,7 +19,7 @@ void c_var(DCELL * result, DCELL * values, int n, const void *closure)
     }
 
     if (count == 0) {
-	G_set_d_null_value(result, 1);
+	Rast_set_d_null_value(result, 1);
 	return;
     }
 
@@ -29,7 +30,7 @@ void c_var(DCELL * result, DCELL * values, int n, const void *closure)
     for (i = 0; i < n; i++) {
 	DCELL d;
 
-	if (G_is_d_null_value(&values[i]))
+	if (Rast_is_d_null_value(&values[i]))
 	    continue;
 
 	d = values[i] - ave;
@@ -49,7 +50,7 @@ void w_var(DCELL * result, DCELL(*values)[2], int n, const void *closure)
     count = 0;
 
     for (i = 0; i < n; i++) {
-	if (G_is_d_null_value(&values[i][0]))
+	if (Rast_is_d_null_value(&values[i][0]))
 	    continue;
 
 	sum += values[i][0] * values[i][1];
@@ -57,7 +58,7 @@ void w_var(DCELL * result, DCELL(*values)[2], int n, const void *closure)
     }
 
     if (count == 0) {
-	G_set_d_null_value(result, 1);
+	Rast_set_d_null_value(result, 1);
 	return;
     }
 
@@ -68,7 +69,7 @@ void w_var(DCELL * result, DCELL(*values)[2], int n, const void *closure)
     for (i = 0; i < n; i++) {
 	DCELL d;
 
-	if (G_is_d_null_value(&values[i][0]))
+	if (Rast_is_d_null_value(&values[i][0]))
 	    continue;
 
 	d = values[i][0] - ave;
