@@ -102,10 +102,10 @@ index_items = [
     ('postscript_graphical.html', std_img_name('cartography'), 'Cartography'),
     ('wxGUI_graphical.html', std_img_name('gui'), 'GUI'),
     ('wxGUI.nviz.html', std_img_name('3dview'), '3D view'),
-    ('https://grass.osgeo.org/grass72/manuals/libpython/index.html', std_img_name('python'), 'Python'),
+    ('https://grass.osgeo.org/grass74/manuals/libpython/index.html', std_img_name('python'), 'Python'),
     ('https://grass.osgeo.org/programming7/', std_img_name('c'), 'C library'),
     ('manual_gallery.html', std_img_name('gallery'), 'Gallery'),
-    ('https://grass.osgeo.org/grass7/manuals/addons/', std_img_name('addons'), 'Addons'),
+    ('http://grass.osgeo.org/grass74/manuals/addons/', std_img_name('addons'), 'Addons'),
 ]
 
 
