@@ -45,8 +45,9 @@
 #include <ctype.h>
 #include <float.h>
 #include <grass/gis.h>
+#include <grass/raster.h>
 #include <grass/dbmi.h>
-#include <grass/Vect.h>
+#include <grass/vector.h>
 #include <grass/glocale.h>
 #include "local_proto.h"
 
@@ -60,12 +61,12 @@ int main(int argc, char *argv[])
     struct Option *max;
     struct Option *step;
     struct Option *cut;
+    struct Flag *notable;
 
     int i;
 
     struct Cell_head Wind;
     char *name;
-    char *mapset;
     struct Map_info Map;
     DCELL **z_array;
     struct FPRange range;
@@ -80,46 +81,47 @@ int main(int argc, char *argv[])
     char buf[2000];
     dbString sql;
 
-    /* please, remove before GRASS 7 released */
-    struct Flag *q_flag;
-    struct Flag *n_flag;
-
-
     G_gisinit(argv[0]);
 
     module = G_define_module();
-    module->keywords = _("raster, DEM, contours, vector");
+    G_add_keyword(_("raster"));
+    G_add_keyword(_("surface"));
+    G_add_keyword(_("contours"));
+    G_add_keyword(_("vector"));
     module->description = _("Produces a vector map of specified "
 			    "contours from a raster map.");
 
     map = G_define_standard_option(G_OPT_R_INPUT);
-
     vect = G_define_standard_option(G_OPT_V_OUTPUT);
 
+    step = G_define_option();
+    step->key = "step";
+    step->type = TYPE_DOUBLE;
+    step->required = NO;
+    step->description = _("Increment between contour levels");
+    step->guisection = _("Contour levels");
+
     levels = G_define_option();
     levels->key = "levels";
     levels->type = TYPE_DOUBLE;
     levels->required = NO;
     levels->multiple = YES;
     levels->description = _("List of contour levels");
+    levels->guisection = _("Contour levels");
 
     min = G_define_option();
     min->key = "minlevel";
     min->type = TYPE_DOUBLE;
     min->required = NO;
     min->description = _("Minimum contour level");
+    min->guisection = _("Contour levels");
 
     max = G_define_option();
     max->key = "maxlevel";
     max->type = TYPE_DOUBLE;
     max->required = NO;
     max->description = _("Maximum contour level");
-
-    step = G_define_option();
-    step->key = "step";
-    step->type = TYPE_DOUBLE;
-    step->required = NO;
-    step->description = _("Increment between contour levels");
+    max->guisection = _("Contour levels");
 
     cut = G_define_option();
     cut->key = "cut";
@@ -129,83 +131,69 @@ int main(int argc, char *argv[])
     cut->description =
 	_("Minimum number of points for a contour line (0 -> no limit)");
 
-    /* please, remove before GRASS 7 released */
-    q_flag = G_define_flag();
-    q_flag->key = 'q';
-    q_flag->description = _("Run quietly");
-    n_flag = G_define_flag();
-    n_flag->key = 'n';
-    n_flag->description = _("Suppress single crossing error messages");
-
+    notable = G_define_standard_flag(G_FLG_V_TABLE);
 
     if (G_parser(argc, argv))
 	exit(EXIT_FAILURE);
 
-    /* please, remove before GRASS 7 released */
-    if (q_flag->answer || n_flag->answer) {
-	G_putenv("GRASS_VERBOSE", "0");
-	G_warning(_("The '-q' and '-n' flag is superseded and will be removed "
-		   "in future. Please use '--quiet' instead."));
-    }
-
     if (!levels->answers && !step->answer) {
-	G_fatal_error(_("Neither \"levels\" nor \"step\" parameter specified."));
+        G_fatal_error(_("Neither <%s> nor <%s> option must be specified"),
+                      levels->key, step->key);
     }
 
     name = map->answer;
-    mapset = G_find_cell2(name, "");
-    if (mapset == NULL)
-	G_fatal_error(_("Raster map <%s> not found"), name);
 
-    fd = G_open_cell_old(name, mapset);
-    if (fd < 0)
-	G_fatal_error(_("Unable to open raster map <%s>"), name);
+    fd = Rast_open_old(name, "");
 
-    if (G_read_fp_range(name, mapset, &range) < 0)
+    if (Rast_read_fp_range(name, "", &range) < 0)
 	G_fatal_error(_("Unable to read fp range of raster map <%s>"),
 		      name);
 
     /* get window info */
     G_get_window(&Wind);
 
-    Vect_open_new(&Map, vect->answer, 1);
+    if (Vect_open_new(&Map, vect->answer, 1) < 0)
+	G_fatal_error(_("Unable to create vector map <%s>"), vect->answer);
+
     Vect_hist_command(&Map);
 
-    db_init_string(&sql);
-
-    /* Open database, create table */
-    Fi = Vect_default_field_info(&Map, 1, NULL, GV_1TABLE);
-    Vect_map_add_dblink(&Map, Fi->number, Fi->name, Fi->table, Fi->key,
-			Fi->database, Fi->driver);
-
-    Driver =
-	db_start_driver_open_database(Fi->driver,
-				      Vect_subst_var(Fi->database, &Map));
-    if (Driver == NULL)
-	G_fatal_error(_("Unable to open database <%s> by driver <%s>"),
-		      Fi->database, Fi->driver);
-
-    sprintf(buf, "create table %s ( cat integer, level double precision )",
-	    Fi->table);
-
-    db_set_string(&sql, buf);
-
-    G_debug(1, "SQL: %s", db_get_string(&sql));
-
-    if (db_execute_immediate(Driver, &sql) != DB_OK) {
-	G_fatal_error(_("Unable to create table: '%s'"),
-		      db_get_string(&sql));
+    if (!notable->answer) {
+        db_init_string(&sql);
+    
+        /* Open database, create table */
+        Fi = Vect_default_field_info(&Map, 1, NULL, GV_1TABLE);
+        Vect_map_add_dblink(&Map, Fi->number, Fi->name, Fi->table, Fi->key,
+                            Fi->database, Fi->driver);
+    
+        Driver =
+            db_start_driver_open_database(Fi->driver,
+                                          Vect_subst_var(Fi->database, &Map));
+        if (Driver == NULL)
+            G_fatal_error(_("Unable to open database <%s> by driver <%s>"),
+                          Fi->database, Fi->driver);
+    
+        sprintf(buf, "create table %s ( cat integer, level double precision )",
+                Fi->table);
+    
+        db_set_string(&sql, buf);
+    
+        G_debug(1, "SQL: %s", db_get_string(&sql));
+    
+        if (db_execute_immediate(Driver, &sql) != DB_OK) {
+            G_fatal_error(_("Unable to create table: '%s'"),
+                          db_get_string(&sql));
+        }
+    
+        if (db_create_index2(Driver, Fi->table, Fi->key) != DB_OK)
+            G_warning(_("Unable to create index for table <%s>, key <%s>"),
+                      Fi->table, Fi->key);
+    
+        if (db_grant_on_table
+            (Driver, Fi->table, DB_PRIV_SELECT, DB_GROUP | DB_PUBLIC) != DB_OK)
+            G_fatal_error(_("Unable to grant privileges on table <%s>"),
+                          Fi->table);
     }
 
-    if (db_create_index2(Driver, Fi->table, Fi->key) != DB_OK)
-	G_warning(_("Unable to create index for table <%s>, key <%s>"),
-		  Fi->table, Fi->key);
-
-    if (db_grant_on_table
-	(Driver, Fi->table, DB_PRIV_SELECT, DB_GROUP | DB_PUBLIC) != DB_OK)
-	G_fatal_error(_("Unable to grant privileges on table <%s>"),
-		      Fi->table);
-
     z_array = get_z_array(fd, Wind.rows, Wind.cols);
     lev = getlevels(levels, max, min, step, &range, &nlevels);
     displaceMatrix(z_array, Wind.rows, Wind.cols, lev, nlevels);
@@ -215,22 +203,23 @@ int main(int argc, char *argv[])
     G_message(_("Writing attributes..."));
     /* Write levels */
 
-    db_begin_transaction(Driver);
-    for (i = 0; i < nlevels; i++) {
-	sprintf(buf, "insert into %s values ( %d, %e )", Fi->table, i + 1,
-		lev[i]);
-	db_set_string(&sql, buf);
-
-	G_debug(3, "SQL: %s", db_get_string(&sql));
-
-	if (db_execute_immediate(Driver, &sql) != DB_OK) {
-	    G_fatal_error(_("Unable to insert new record: '%s'"), db_get_string(&sql));
-	}
+    if (!notable->answer) {
+        db_begin_transaction(Driver);
+        for (i = 0; i < nlevels; i++) {
+            sprintf(buf, "insert into %s values ( %d, %e )", Fi->table, i + 1,
+                    lev[i]);
+            db_set_string(&sql, buf);
+            
+            G_debug(3, "SQL: %s", db_get_string(&sql));
+            
+            if (db_execute_immediate(Driver, &sql) != DB_OK) {
+                G_fatal_error(_("Unable to insert new record: '%s'"), db_get_string(&sql));
+            }
+        }
+        db_commit_transaction(Driver);
+        
+        db_close_database_shutdown_driver(Driver);
     }
-    db_commit_transaction(Driver);
-
-    db_close_database_shutdown_driver(Driver);
-
     Vect_build(&Map);
     Vect_close(&Map);
 
@@ -249,7 +238,7 @@ DCELL **get_z_array(int fd, int nrow, int ncol)
 
     for (i = 0; i < nrow; i++) {
 	z_array[i] = (DCELL *) G_malloc(ncol * sizeof(DCELL));
-	G_get_d_raster_row(fd, z_array[i], i);
+	Rast_get_d_row(fd, z_array[i], i);
 	G_percent(i + 1, nrow, 2);
     }
     return z_array;
@@ -268,9 +257,9 @@ double *getlevels(struct Option *levels,
     double *lev;
     double tmp;
 
-    G_get_fp_range_min_max(range, &zmin, &zmax);
+    Rast_get_fp_range_min_max(range, &zmin, &zmax);
 
-    if (!G_is_d_null_value(&zmin) && !G_is_d_null_value(&zmax))
+    if (!Rast_is_d_null_value(&zmin) && !Rast_is_d_null_value(&zmax))
 	G_verbose_message(_("Range of data: min=%f, max=%f"), zmin, zmax);
     else
 	G_verbose_message(_("Range of data: empty"));
@@ -299,13 +288,14 @@ double *getlevels(struct Option *levels,
 
 	dstep = atof(step->answer);
 	/* fix if step < 1, Roger Bivand 1/2001: */
-	dmax = (max->answer) ? atof(max->answer) : dstep == 0 ?
-	    G_fatal_error(_("This step value is not allowed")) : zmax -
-	    fmod(zmax, dstep);
-	dmin =
-	    (min->answer) ? atof(min->answer) : dstep ==
-	    0 ? G_fatal_error(_("This step value is not allowed")) :
-	    fmod(zmin, dstep) ? zmin - fmod(zmin, dstep) + dstep : zmin;
+
+	dmax = (max->answer) ? atof(max->answer) :
+	    dstep == 0 ? (G_fatal_error(_("This step value is not allowed")), 0) :
+	    zmax - fmod(zmax, dstep);
+	dmin = (min->answer) ? atof(min->answer) :
+	    dstep == 0 ? (G_fatal_error(_("This step value is not allowed")), 0) :
+	    fmod(zmin, dstep) ? zmin - fmod(zmin, dstep) + dstep :
+	    zmin;
 
 	while (dmin < zmin) {
 	    dmin += dstep;
