@@ -4,19 +4,24 @@
  * MODULE:       r.distance
  *
  * AUTHOR(S):    Michael Shapiro - CERL
+ *               Sort/reverse sort by distance by Huidae Cho
  *
- * PURPOSE:      Locates the closest points between objects in two
+ * PURPOSE:      Locates the closest points between objects in two 
  *               raster maps.
  *
- * COPYRIGHT:    (C) 2003 by the GRASS Development Team
+ * COPYRIGHT:    (C) 2003-2014 by the GRASS Development Team
  *
- *               This program is free software under the GNU General Public
- *               License (>=v2). Read the file COPYING that comes with GRASS
- *               for details.
+ *               This program is free software under the GNU General
+ *               Public License (>=v2). Read the file COPYING that
+ *               comes with GRASS for details.
  *
  ***************************************************************************/
 
 #include <stdlib.h>
+
+#include <grass/raster.h>
+#include <grass/glocale.h>
+
 #include "defs.h"
 
 void print_edge_info(struct Map *map)
@@ -29,7 +34,7 @@ void print_edge_info(struct Map *map)
     fprintf(stdout, "\n");
 }
 
-void find_edge_cells(struct Map *map)
+void find_edge_cells(struct Map *map, int null)
 {
     void init_edge_list();
     void add_edge_cell();
@@ -41,8 +46,8 @@ void find_edge_cells(struct Map *map)
 
     G_message(_("Reading map %s ..."), map->fullname);
 
-    ncols = G_window_cols();
-    nrows = G_window_rows();
+    ncols = Rast_window_cols();
+    nrows = Rast_window_rows();
 
     buf0 = (CELL *) G_calloc(ncols + 2, sizeof(CELL));
     buf1 = (CELL *) G_calloc(ncols + 2, sizeof(CELL));
@@ -54,9 +59,7 @@ void find_edge_cells(struct Map *map)
 	buf2[col] = 0;
     }
 
-    fd = G_open_cell_old(map->name, map->mapset);
-    if (fd < 0)
-	exit(1);
+    fd = Rast_open_old(map->name, map->mapset);
 
     init_edge_list(map);
 
@@ -69,21 +72,21 @@ void find_edge_cells(struct Map *map)
 	buf2 = tmp;
 
 	/* read a row */
-	if (G_get_map_row(fd, &buf1[1], row) < 0)
-	    exit(1);
+	Rast_get_c_row(fd, &buf1[1], row);
 
 	for (col = 1; col <= ncols; col++) {
-	    if (buf1[col]	/* is a valid category */
+	    if ((buf1[col]	/* is a valid category */
 		&&(buf1[col - 1] != buf1[col]	/* 4 neighbors not the same? */
 		   ||buf1[col + 1] != buf1[col]
 		   || buf0[col] != buf1[col]
-		   || buf2[col] != buf1[col]))
+		   || buf2[col] != buf1[col])) &&
+		(null || !Rast_is_c_null_value(&buf1[col])))
 		add_edge_cell(map, buf1[col], row, col - 1);
 	}
     }
     G_percent(row, nrows, 2);
 
-    G_close_cell(fd);
+    Rast_close(fd);
 
     G_free(buf0);
     G_free(buf1);
