@@ -38,7 +38,7 @@ void list_formats(void);
 void list_bands(struct Cell_head *, GDALDatasetH);
 
 /* proj.c */
-void check_projection(struct Cell_head *, GDALDatasetH, int);
+void check_projection(struct Cell_head *, GDALDatasetH, char *, int, int, int);
 
 /* window.c */
 void setup_window(struct Cell_head *, GDALDatasetH, int *);
