@@ -15,7 +15,6 @@
  * \include
  * 
  */
-#include <grass/config.h>
 #include <stdlib.h>
 #include <stddef.h>
 #include <fcntl.h>
@@ -32,14 +31,10 @@
 #endif
 
 #include <grass/gis.h>
+#include <grass/raster.h>
 #include <grass/glocale.h>
 #include "daemon.h"
 
-#ifdef __MINGW32__
-#define srandom srand
-#define random rand
-#endif
-
 int calculateIndex(char *file, rli_func *f,
 		   char **parameters, char *raster, char *output)
 {
@@ -72,14 +67,16 @@ int calculateIndex(char *file, rli_func *f,
     char rlipath[GPATH_MAX];
     char testpath[GPATH_MAX];
 
-    sprintf(rlipath, "%s%c%s%c", G_home(), HOST_DIRSEP, ".r.li", HOST_DIRSEP);
+	/* conf files go into ~/.grass7/r.li/ */
+    sprintf(rlipath, "%s%c%s%c", G_config_path(), HOST_DIRSEP, "r.li", HOST_DIRSEP);
 
-    sprintf(testpath, "%s%s%c", rlipath, "history", HOST_DIRSEP);
+    sprintf(testpath, "%s%c%s%c", G_config_path(), HOST_DIRSEP, "r.li", HOST_DIRSEP);
     if (strncmp(file, testpath, strlen(testpath)) == 0)
 	file += strlen(testpath);
 
+    /* TODO: check if this path is portable */
     /* TODO: use G_rc_path() */
-    sprintf(pathSetup, "%s%s%c%s", rlipath, "history", HOST_DIRSEP, file);
+    sprintf(pathSetup, "%s%s", rlipath, file);
     G_debug(1, "r.li.daemon pathSetup: [%s]", pathSetup);
     parsed = parseSetup(pathSetup, l, g, raster);
 
@@ -92,9 +89,7 @@ int calculateIndex(char *file, rli_func *f,
 	/* struct Cell_head cellhd_r, cellhd_new;
 	   char *mapset; */
 	/*creating new raster file */
-	mv_fd = G_open_raster_new(output, DCELL_TYPE);
-	if (mv_fd < 0)
-	    G_fatal_error(_("Unable to create raster map <%s>"), output);
+	mv_fd = Rast_open_new(output, DCELL_TYPE);
 
 	random_access_name = G_tempfile();
 	random_access = open(random_access_name, O_RDWR | O_CREAT, 0755);
@@ -103,18 +98,23 @@ int calculateIndex(char *file, rli_func *f,
     }
     else {
 	/* text file output */
-	/* check if ~/.r.li/ exists */
+	/* check if ~/.grass7/ exists */
+        sprintf(out, "%s", G_config_path());
+	doneDir = G_mkdir(out);
+	if (doneDir == -1 && errno != EEXIST)
+	    G_fatal_error(_("Cannot create %s directory"), out);
+
+	/* check if ~/.grass7/r.li/ exists */
 	sprintf(out, "%s", rlipath);
 	doneDir = G_mkdir(out);
 	if (doneDir == -1 && errno != EEXIST)
-	    G_fatal_error(_("Cannot create %s directory"), rlipath);
+	    G_fatal_error(_("Cannot create %s directory"), out);
 
-	/* check if ~/.r.li/output/ exists */
-	sprintf(out, "%s%s%c", rlipath, "output", HOST_DIRSEP);
+	/* check if ~/.grass7/r.li/output exists */
+	sprintf(out, "%s%s", rlipath, "output");
 	doneDir = G_mkdir(out);
 	if (doneDir == -1 && errno != EEXIST)
-	    G_fatal_error(_("Cannot create %s%s%c directory"), rlipath, "output", HOST_DIRSEP);
-
+	    G_fatal_error(_("Cannot create %s directory"), out);
 	sprintf(out, "%s%s%c%s", rlipath, "output", HOST_DIRSEP, output);
 	res = open(out, O_WRONLY | O_CREAT | O_TRUNC, 0644);
     }
@@ -167,17 +167,19 @@ int calculateIndex(char *file, rli_func *f,
 	write_raster(mv_fd, random_access, g);
 	close(random_access);
 	unlink(random_access_name);
-	G_close_cell(mv_fd);
-	G_short_history(output, "raster", &history);
-	G_command_history(&history);
-	G_write_history(output, &history);
+	Rast_close(mv_fd);
+	Rast_short_history(output, "raster", &history);
+	Rast_command_history(&history);
+	Rast_write_history(output, &history);
 	G_done_msg(_("Raster map <%s> created."), output);
     } else {
 	/* text file output */
-	G_message("Result written to text file <%s>", out);
+	G_done_msg("Result written to text file <%s>", out);
     }
 
-    return 1;
+    /* This is only return in this function, so the documented 1 is
+       actually never returned. */
+    return 0;
 }
 
 
@@ -185,7 +187,7 @@ int parseSetup(char *path, struct list *l, struct g_area *g, char *raster)
 {
     struct stat s;
     struct Cell_head cellhd;
-    char *buf, *mapset; /* *raster_fqn, */
+    char *buf;
     const char *token;
     int setup;
     int letti;
@@ -218,12 +220,8 @@ int parseSetup(char *path, struct list *l, struct g_area *g, char *raster)
     rel_rl = atof(strtok(NULL, "|"));
     rel_cl = atof(strtok(NULL, "\n"));
 
-    /* find raster map */
-    mapset = G_find_cell(raster, "");
-/*    raster_fqn = G_fully_qualified_name(raster, mapset); */
-   
     /* use current region ! */
-    G_get_window(&cellhd);
+    Rast_get_window(&cellhd);
 
     /* calculate absolute sampling frame definition */
     sf_x = (int)rint(cellhd.cols * rel_x);
@@ -417,7 +415,7 @@ int parseSetup(char *path, struct list *l, struct g_area *g, char *raster)
 	char maskname[GNAME_MAX] = {'\0'};
 	msg m;
 
-	/* Get the window setting. g.region rast=<input raster> */
+	/* Get the window setting. g.region raster=<input raster> */
 	/*   ? same as cellhd above ? */
 	/* no. the current window might be different */
 
@@ -477,10 +475,9 @@ int parseSetup(char *path, struct list *l, struct g_area *g, char *raster)
 	    G_fatal_error(_("Irregular MASKEDOVERLAY areas definition"));
 
 	token = strtok(NULL, "\n");
-/*	if (strcmp(token, raster_fqn) != 0)
-	    G_fatal_error(_("The configuration file can be used only with "
-			"rasterfile <%s> and not with <%s>"), token, raster_fqn); */
-
+	if (strcmp(token, raster) != 0)
+	    G_fatal_error(_("The configuration file can only be used "
+			    "with the <%s> raster map"), token);
 	close(setup);
 	return NORMAL;
     }
@@ -523,11 +520,11 @@ int disposeAreas(struct list *l, struct g_area *g, char *def)
 	    G_fatal_error(_("Too many units to place"));
 	assigned = G_malloc(units * sizeof(int));
 	i = 0;
-	srandom(getpid());
+	G_srand48(0);
 	while (i < units) {
 	    int j, position, found = FALSE;
 
-	    position = random() % max_units;
+	    position = G_lrand48() % max_units;
 	    for (j = 0; j < i; j++) {
 		if (assigned[j] == position)
 		    found = TRUE;
@@ -591,7 +588,7 @@ int disposeAreas(struct list *l, struct g_area *g, char *def)
 	if (r_strat_len < g->rl || c_strat_len < g->cl)
 	    G_fatal_error(_("Too many stratified random sample for raster map"));
 	loop = r_strat * c_strat;
-	srandom(getpid());
+	G_srand48(0);
 	for (i = 0; i < loop; i++) {
 	    msg m;
 
@@ -599,9 +596,9 @@ int disposeAreas(struct list *l, struct g_area *g, char *def)
 		m.type = AREA;
 		m.f.f_a.aid = i;
 		m.f.f_a.x = (int)g->sf_x + ((i % c_strat) * c_strat_len) +
-		    (random() % (c_strat_len - g->cl));
+		    (G_lrand48() % (c_strat_len - g->cl));
 		m.f.f_a.y = (int)g->sf_y + (rint(i / c_strat) * r_strat_len) +
-		    (random() % (r_strat_len - g->rl));
+		    (G_lrand48() % (r_strat_len - g->rl));
 		m.f.f_a.rl = g->rl;
 		m.f.f_a.cl = g->cl;
 		insertNode(l, m);
@@ -610,10 +607,10 @@ int disposeAreas(struct list *l, struct g_area *g, char *def)
 		m.type = MASKEDAREA;
 		m.f.f_ma.aid = i;
 		m.f.f_ma.x = (int)g->sf_x + ((i % c_strat) * c_strat_len) +
-		    (random() % (c_strat_len - g->cl));
+		    (G_lrand48() % (c_strat_len - g->cl));
 		m.f.f_ma.y =
 		    (int)g->sf_y + (rint(i / c_strat) * r_strat_len) +
-		    (random() % (r_strat_len - g->rl));
+		    (G_lrand48() % (r_strat_len - g->rl));
 		m.f.f_ma.rl = g->rl;
 		m.f.f_ma.cl = g->cl;
 		strcpy(m.f.f_ma.mask, g->maskname);
@@ -658,7 +655,7 @@ int print_Output(int out, msg m)
 	char s[100];
 	int len;
 
-	if (G_is_null_value(&m.f.f_d.res, DCELL_TYPE))
+	if (Rast_is_d_null_value(&m.f.f_d.res))
 	    sprintf(s, "RESULT %i|NULL\n", m.f.f_d.aid);
 	else
 	    sprintf(s, "RESULT %i|%.15g\n", m.f.f_d.aid, m.f.f_d.res);
@@ -720,11 +717,11 @@ int write_raster(int mv_fd, int random_access, struct g_area *g)
     file_buf = G_malloc(cols * sizeof(double));
     lseek(random_access, 0, SEEK_SET);
 
-    cell_buf = G_allocate_d_raster_buf();
-    G_set_d_null_value(cell_buf, G_window_cols() + 1);
+    cell_buf = Rast_allocate_d_buf();
+    Rast_set_d_null_value(cell_buf, Rast_window_cols() + 1);
 
     for (i = 0; i < g->sf_y + ((int)g->rl / 2); i++) {
-	G_put_raster_row(mv_fd, cell_buf, DCELL_TYPE);
+	Rast_put_row(mv_fd, cell_buf, DCELL_TYPE);
     }
 
     for (i = 0; i < rows; i++) {
@@ -737,14 +734,14 @@ int write_raster(int mv_fd, int random_access, struct g_area *g)
 	    cell_buf[j + center] = file_buf[j];
 	}
 
-	G_put_raster_row(mv_fd, cell_buf, DCELL_TYPE);
+	Rast_put_row(mv_fd, cell_buf, DCELL_TYPE);
 
     }
 
-    G_set_d_null_value(cell_buf, G_window_cols() + 1);
+    Rast_set_d_null_value(cell_buf, Rast_window_cols() + 1);
 
-    for (i = 0; i < G_window_rows() - g->sf_y - g->rows; i++)
-	G_put_raster_row(mv_fd, cell_buf, DCELL_TYPE);
+    for (i = 0; i < Rast_window_rows() - g->sf_y - g->rows; i++)
+	Rast_put_row(mv_fd, cell_buf, DCELL_TYPE);
 
     return 1;
 }
