@@ -22,6 +22,7 @@
 #include <math.h>
 
 #include <grass/gis.h>
+#include <grass/raster.h>
 #include <grass/glocale.h>
 
 #include "../r.li.daemon/daemon.h"
@@ -49,13 +50,15 @@ int main(int argc, char *argv[])
     module = G_define_module();
     module->description =
 	_("Calculates coefficient of variation of patch area on a raster map");
-    module->keywords = _("raster, landscape structure analysis, patch index");
+    G_add_keyword(_("raster"));
+    G_add_keyword(_("landscape structure analysis"));
+    G_add_keyword(_("patch index"));
 
     /* define options */
-    raster = G_define_standard_option(G_OPT_R_MAP);
+    raster = G_define_standard_option(G_OPT_R_INPUT);
 
     conf = G_define_standard_option(G_OPT_F_INPUT);
-    conf->key = "conf";
+    conf->key = "config";
     conf->description = _("Configuration file");
     conf->required = YES;
 
@@ -119,17 +122,17 @@ int calculate(int fd, struct area_entry *ad, double *result)
     int mask_fd, *mask_buf, *mask_sup, *mask_tmp, masked;
     struct Cell_head hd;
 
-    G_get_window(&hd);
+    Rast_get_window(&hd);
 
-    buf_null = G_allocate_cell_buf();
-    G_set_c_null_value(buf_null, G_window_cols());
+    buf_null = Rast_allocate_c_buf();
+    Rast_set_c_null_value(buf_null, Rast_window_cols());
     buf_sup = buf_null;
 
     /* initialize patch ids */
-    pid_corr = G_malloc(G_window_cols() * sizeof(long));
-    pid_sup = G_malloc(G_window_cols() * sizeof(long));
+    pid_corr = G_malloc(Rast_window_cols() * sizeof(long));
+    pid_sup = G_malloc(Rast_window_cols() * sizeof(long));
 
-    for (j = 0; j < G_window_cols(); j++) {
+    for (j = 0; j < Rast_window_cols(); j++) {
 	pid_corr[j] = 0;
 	pid_sup[j] = 0;
     }
@@ -194,7 +197,7 @@ int calculate(int fd, struct area_entry *ad, double *result)
 	pid_sup = pid_corr;
 	pid_corr = ltmp;
 
-	G_set_c_null_value(&precCell, 1);
+	Rast_set_c_null_value(&precCell, 1);
 
 	connected = 0;
 	for (j = 0; j < ad->cl; j++) {
@@ -202,10 +205,10 @@ int calculate(int fd, struct area_entry *ad, double *result)
 	    
 	    corrCell = buf[j + ad->x];
 	    if (masked && (mask_buf[j] == 0)) {
-		G_set_c_null_value(&corrCell, 1);
+		Rast_set_c_null_value(&corrCell, 1);
 	    }
 
-	    if (G_is_c_null_value(&corrCell)) {
+	    if (Rast_is_c_null_value(&corrCell)) {
 		connected = 0;
 		precCell = corrCell;
 		continue;
@@ -215,10 +218,10 @@ int calculate(int fd, struct area_entry *ad, double *result)
 	    
 	    supCell = buf_sup[j + ad->x];
 	    if (masked && (mask_sup[j] == 0)) {
-		G_set_c_null_value(&supCell, 1);
+		Rast_set_c_null_value(&supCell, 1);
 	    }
 
-	    if (!G_is_c_null_value(&precCell) && corrCell == precCell) {
+	    if (!Rast_is_c_null_value(&precCell) && corrCell == precCell) {
 		pid_corr[j + ad->x] = pid_corr[j - 1 + ad->x];
 		connected = 1;
 		pst[pid_corr[j + ad->x]].count++;
@@ -227,7 +230,7 @@ int calculate(int fd, struct area_entry *ad, double *result)
 		connected = 0;
 	    }
 
-	    if (!G_is_c_null_value(&supCell) && corrCell == supCell) {
+	    if (!Rast_is_c_null_value(&supCell) && corrCell == supCell) {
 
 		if (pid_corr[j + ad->x] != pid_sup[j + ad->x]) {
 		    /* connect or merge */
@@ -333,7 +336,7 @@ int calculate(int fd, struct area_entry *ad, double *result)
 	*result = pcv;
     }
     else
-	G_set_d_null_value(result, 1);
+	Rast_set_d_null_value(result, 1);
 
     if (masked) {
 	close(mask_fd);
@@ -362,17 +365,17 @@ int calculateD(int fd, struct area_entry *ad, double *result)
     int mask_fd, *mask_buf, *mask_sup, *mask_tmp, masked;
     struct Cell_head hd;
 
-    G_get_window(&hd);
+    Rast_get_window(&hd);
 
-    buf_null = G_allocate_d_raster_buf();
-    G_set_d_null_value(buf_null, G_window_cols());
+    buf_null = Rast_allocate_d_buf();
+    Rast_set_d_null_value(buf_null, Rast_window_cols());
     buf_sup = buf_null;
 
     /* initialize patch ids */
-    pid_corr = G_malloc(G_window_cols() * sizeof(long));
-    pid_sup = G_malloc(G_window_cols() * sizeof(long));
+    pid_corr = G_malloc(Rast_window_cols() * sizeof(long));
+    pid_sup = G_malloc(Rast_window_cols() * sizeof(long));
 
-    for (j = 0; j < G_window_cols(); j++) {
+    for (j = 0; j < Rast_window_cols(); j++) {
 	pid_corr[j] = 0;
 	pid_sup[j] = 0;
     }
@@ -437,7 +440,7 @@ int calculateD(int fd, struct area_entry *ad, double *result)
 	pid_sup = pid_corr;
 	pid_corr = ltmp;
 
-	G_set_d_null_value(&precCell, 1);
+	Rast_set_d_null_value(&precCell, 1);
 
 	connected = 0;
 	for (j = 0; j < ad->cl; j++) {
@@ -445,10 +448,10 @@ int calculateD(int fd, struct area_entry *ad, double *result)
 	    
 	    corrCell = buf[j + ad->x];
 	    if (masked && (mask_buf[j] == 0)) {
-		G_set_d_null_value(&corrCell, 1);
+		Rast_set_d_null_value(&corrCell, 1);
 	    }
 
-	    if (G_is_d_null_value(&corrCell)) {
+	    if (Rast_is_d_null_value(&corrCell)) {
 		connected = 0;
 		precCell = corrCell;
 		continue;
@@ -458,10 +461,10 @@ int calculateD(int fd, struct area_entry *ad, double *result)
 	    
 	    supCell = buf_sup[j + ad->x];
 	    if (masked && (mask_sup[j] == 0)) {
-		G_set_d_null_value(&supCell, 1);
+		Rast_set_d_null_value(&supCell, 1);
 	    }
 
-	    if (!G_is_d_null_value(&precCell) && corrCell == precCell) {
+	    if (!Rast_is_d_null_value(&precCell) && corrCell == precCell) {
 		pid_corr[j + ad->x] = pid_corr[j - 1 + ad->x];
 		connected = 1;
 		pst[pid_corr[j + ad->x]].count++;
@@ -470,7 +473,7 @@ int calculateD(int fd, struct area_entry *ad, double *result)
 		connected = 0;
 	    }
 
-	    if (!G_is_d_null_value(&supCell) && corrCell == supCell) {
+	    if (!Rast_is_d_null_value(&supCell) && corrCell == supCell) {
 
 		if (pid_corr[j + ad->x] != pid_sup[j + ad->x]) {
 		    /* connect or merge */
@@ -576,7 +579,7 @@ int calculateD(int fd, struct area_entry *ad, double *result)
 	*result = pcv;
     }
     else
-	G_set_d_null_value(result, 1);
+	Rast_set_d_null_value(result, 1);
 
     if (masked) {
 	close(mask_fd);
@@ -605,17 +608,17 @@ int calculateF(int fd, struct area_entry *ad, double *result)
     int mask_fd, *mask_buf, *mask_sup, *mask_tmp, masked;
     struct Cell_head hd;
 
-    G_get_window(&hd);
+    Rast_get_window(&hd);
 
-    buf_null = G_allocate_f_raster_buf();
-    G_set_f_null_value(buf_null, G_window_cols());
+    buf_null = Rast_allocate_f_buf();
+    Rast_set_f_null_value(buf_null, Rast_window_cols());
     buf_sup = buf_null;
 
     /* initialize patch ids */
-    pid_corr = G_malloc(G_window_cols() * sizeof(long));
-    pid_sup = G_malloc(G_window_cols() * sizeof(long));
+    pid_corr = G_malloc(Rast_window_cols() * sizeof(long));
+    pid_sup = G_malloc(Rast_window_cols() * sizeof(long));
 
-    for (j = 0; j < G_window_cols(); j++) {
+    for (j = 0; j < Rast_window_cols(); j++) {
 	pid_corr[j] = 0;
 	pid_sup[j] = 0;
     }
@@ -680,7 +683,7 @@ int calculateF(int fd, struct area_entry *ad, double *result)
 	pid_sup = pid_corr;
 	pid_corr = ltmp;
 
-	G_set_f_null_value(&precCell, 1);
+	Rast_set_f_null_value(&precCell, 1);
 
 	connected = 0;
 	for (j = 0; j < ad->cl; j++) {
@@ -688,10 +691,10 @@ int calculateF(int fd, struct area_entry *ad, double *result)
 	    
 	    corrCell = buf[j + ad->x];
 	    if (masked && (mask_buf[j] == 0)) {
-		G_set_f_null_value(&corrCell, 1);
+		Rast_set_f_null_value(&corrCell, 1);
 	    }
 
-	    if (G_is_f_null_value(&corrCell)) {
+	    if (Rast_is_f_null_value(&corrCell)) {
 		connected = 0;
 		precCell = corrCell;
 		continue;
@@ -701,10 +704,10 @@ int calculateF(int fd, struct area_entry *ad, double *result)
 	    
 	    supCell = buf_sup[j + ad->x];
 	    if (masked && (mask_sup[j] == 0)) {
-		G_set_f_null_value(&supCell, 1);
+		Rast_set_f_null_value(&supCell, 1);
 	    }
 
-	    if (!G_is_f_null_value(&precCell) && corrCell == precCell) {
+	    if (!Rast_is_f_null_value(&precCell) && corrCell == precCell) {
 		pid_corr[j + ad->x] = pid_corr[j - 1 + ad->x];
 		connected = 1;
 		pst[pid_corr[j + ad->x]].count++;
@@ -713,7 +716,7 @@ int calculateF(int fd, struct area_entry *ad, double *result)
 		connected = 0;
 	    }
 
-	    if (!G_is_f_null_value(&supCell) && corrCell == supCell) {
+	    if (!Rast_is_f_null_value(&supCell) && corrCell == supCell) {
 
 		if (pid_corr[j + ad->x] != pid_sup[j + ad->x]) {
 		    /* connect or merge */
@@ -819,7 +822,7 @@ int calculateF(int fd, struct area_entry *ad, double *result)
 	*result = pcv;
     }
     else
-	G_set_d_null_value(result, 1);
+	Rast_set_d_null_value(result, 1);
 
     if (masked) {
 	close(mask_fd);
