@@ -24,7 +24,9 @@ extern FLAG *Cells;
 extern CELLSORTER *DoNext;
 extern CELL **Out, *CellBuffer;
 extern int Seed, OutFD;
+extern int MaxCellsNum;
 extern struct Flag *Verbose;
 extern struct Option *Distance;
 extern struct Option *Output;
 extern struct Option *SeedStuff;
+extern struct Option *MaxCells;
