@@ -1,3 +1,5 @@
+#include <grass/raster.h>
+
 #define         SHORT           short
 #define         TRUE    1
 #define         FALSE   0
@@ -32,45 +34,6 @@ EW {
     EW *next;
 };
 
-#ifdef MAIN
-
-struct Cell_head window;
-CELL *cell, *mask;
-double *rowlook, *collook, *lat_diff,	/* distances between latitudes */
-  ew2;
-
-short ll;			/* TRUE if latitude-longitude projection */
-
-/* function pointers for LL function substitutes */
-
-int first_west(EW *, SHORT);
-int first_west_LL(EW *, SHORT);
-int (*init_row_search) (EW *, SHORT);	/* function pointer */
-
-int completed_row(EW *);
-int completed_row_LL(EW *);
-
- /* function pointer */
-int (*comp_row_search) (EW *);
-
-int find_neighbors(EW *, NEIGHBOR *, SHORT, SHORT, int, SHORT *);
-int find_neighbors_LL(EW *, NEIGHBOR *, SHORT, SHORT, int, SHORT *);
-
- /* function pointer */
-int (*locate_neighbors) (EW *, NEIGHBOR *, SHORT, SHORT, int, SHORT *);
-
-int exhaust_search(EW *, NEIGHBOR *, SHORT, SHORT);
-int exhaust_search_LL(EW *, NEIGHBOR *, SHORT, SHORT);
-
-/* function pointer */
-int (*exhaust_row) (EW *, NEIGHBOR *, SHORT, SHORT);
-
-double offset_distance(SHORT);
-double offset_distance_LL(SHORT);
-double (*check_offset) (SHORT);	/* function pointer */
-
-#endif
-
 /* dist.c */
 int G_begin_geodesic_distance_l(short, double, double);
 double LL_set_geodesic_distance_lat(double);
