@@ -73,6 +73,11 @@ int main(int argc, char *argv[])
     G_add_keyword(_("raster"));
     G_add_keyword(_("hydrology"));
     G_add_keyword(_("watershed"));
+    G_add_keyword(_("accumulation"));
+    G_add_keyword(_("drainage"));
+    G_add_keyword(_("stream network"));
+    G_add_keyword(_("stream power index"));
+    G_add_keyword(_("topographic index"));
     module->description = _("Calculates hydrological parameters and RUSLE factors.");
 
     opt1 = G_define_standard_option(G_OPT_R_ELEV);
@@ -149,7 +154,8 @@ int main(int argc, char *argv[])
 
     opt9 = G_define_standard_option(G_OPT_R_OUTPUT);
     opt9->key = "drainage";
-    opt9->description = _("Name for output drainage direction raster map");
+    opt9->label = _("Name for output drainage direction raster map");
+    opt9->description = _("Directions numbered from 1 to 8");
     opt9->required = NO;
     opt9->guisection = _("Outputs");
 
