@@ -1,11 +1,11 @@
 #include <grass/gis.h>
 #include <unistd.h>
 #include <grass/segment.h>
-#include "cseg.h"
+#include "Gwater.h"
 
 int seg_close(SSEG * sseg)
 {
-    segment_release(&(sseg->seg));
+    Segment_release(&(sseg->seg));
     close(sseg->fd);
     unlink(sseg->filename);
     return 0;
