@@ -32,6 +32,11 @@ from grass.script.utils import try_remove
 from grass.script import core as gcore
 from grass.exceptions import CalledModuleError
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
+
 def main():
     layers = options['map'].split(',')
 
