@@ -40,6 +40,11 @@
 
 from grass.script import core as gcore
 
+# i18N
+import os
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def main():
     options, flags = gcore.parser()
