@@ -65,6 +65,10 @@ import sys
 import os
 import grass.script as grass
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def make_frame(f, b, t, l, r):
     (fl, fr, ft, fb) = f
