@@ -41,6 +41,11 @@ import string
 from grass.exceptions import CalledModuleError
 import grass.script as gscript
 
+# i18N
+import os
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def main():
     table = options['table']
