@@ -61,6 +61,11 @@ import math
 
 import grass.script as gscript
 
+# i18N
+import os
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def cleanup():
     for ext in ['', '.sort']:
