@@ -47,6 +47,10 @@ except ImportError:
 import grass.script as gscript
 from grass.exceptions import CalledModuleError
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def get_extensions():
     addon_base = os.getenv('GRASS_ADDON_BASE')
