@@ -60,6 +60,10 @@ import webbrowser
 from grass.script.utils import basename
 from grass.script import core as grass
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def start_browser(entry):
     if browser and \
