@@ -103,6 +103,10 @@ import atexit
 import grass.script as grass
 from grass.exceptions import CalledModuleError
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 tmp_rmaps = list()
 tmp_vmaps = list()
 usermask = None
@@ -336,8 +340,11 @@ def main():
 
             # Avoid v.surf.rst warnings
             if pointsnumber < segmax:
-                npmin = pointsnumber + 1
-                segmax = pointsnumber
+                use_npmin = pointsnumber
+                use_segmax = pointsnumber * 2
+            else:
+                use_npmin = npmin
+                use_segmax = segmax
 
             # launch v.surf.rst
             tmp_rmaps.append(holename + '_dem')
@@ -345,7 +352,7 @@ def main():
                 grass.run_command('v.surf.rst', quiet=quiet,
                                   input=holename, elev=holename + '_dem',
                                   tension=tension, smooth=smooth,
-                                  segmax=segmax, npmin=npmin)
+                                  segmax=use_segmax, npmin=use_npmin)
             except CalledModuleError:
                 # GTC Hole is NULL area in a raster map
                 grass.fatal(_("Failed to fill hole %s") % cat)
