@@ -67,6 +67,10 @@ import math
 import grass.script as grass
 from grass.exceptions import CalledModuleError
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 # what to do in case of user break:
 def cleanup():
