@@ -56,6 +56,10 @@ import os
 import platform
 import grass.script as grass
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 bands = {
     'L1A': {
         '1': "VNIR_Band1:ImageData",
