@@ -113,6 +113,10 @@ import atexit
 import grass.script as grass
 from grass.exceptions import CalledModuleError
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def cleanup():
     if not in_temp:
@@ -135,7 +139,7 @@ def main():
     # are we in LatLong location?
     s = grass.read_command("g.proj", flags='j')
     kv = grass.parse_key_val(s)
-    if kv['+proj'] != 'longlat':
+    if not '+proj' in kv.keys() or kv['+proj'] != 'longlat':
         grass.fatal(_("This module only operates in LatLong locations"))
 
     # use these from now on:
