@@ -16,6 +16,10 @@ This program is free software under the GNU General Public License
 import os
 import grass.script as grass
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 try:
     from osgeo import gdal
     from osgeo import gdalconst
