@@ -77,6 +77,10 @@ import os
 import atexit
 import grass.script as grass
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 TMPRAST = []
 
 
