@@ -43,6 +43,11 @@
 
 import grass.script as gscript
 
+# i18N
+import os
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def main():
     options, unused = gscript.parser()
