@@ -26,6 +26,10 @@
 #% keyword: import
 #% keyword: voxel
 #% keyword: LIDAR
+#% keyword: statistics
+#% keyword: conversion
+#% keyword: aggregation
+#% keyword: binning
 #%End
 #%Flag
 #% key: s
@@ -170,6 +174,10 @@ import atexit
 from grass.script import core as grass
 from grass.exceptions import CalledModuleError
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def cleanup():
     grass.run_command('g.remove', flags='f',
