@@ -22,6 +22,11 @@ import sys
 from grass.script import core as grass
 from grass.exceptions import CalledModuleError
 
+# i18N
+import os
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def main():
     env = grass.gisenv()
