@@ -57,6 +57,10 @@ import os
 import grass.script as grass
 from grass.exceptions import CalledModuleError
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def main():
     vector = options['map']
