@@ -39,6 +39,10 @@ import os
 import grass.script as gscript
 from grass.exceptions import CalledModuleError
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def main():
     force = flags['f']
