@@ -61,6 +61,11 @@ import string
 import grass.script as grass
 from grass.exceptions import CalledModuleError
 
+# i18N
+import os
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def main():
     map = options['map']
