@@ -56,6 +56,10 @@ import string
 import grass.script as gscript
 from grass.exceptions import CalledModuleError
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 # substitute variables (gisdbase, location_name, mapset)
 
 
