@@ -54,6 +54,10 @@ import sys
 import os
 import grass.script as grass
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def main():
     vector = options['map']
