@@ -63,8 +63,8 @@
 #% key: snap
 #% type: double
 #% label: Snapping threshold for boundaries (map units)
-#% description: '-1' for no snap
-#% answer: 1e-13
+#% description: A suitable threshold is estimated during import
+#% answer: -1
 #% guisection: Output
 #%end
 #%option
@@ -104,6 +104,10 @@ import atexit
 import grass.script as grass
 from grass.exceptions import CalledModuleError
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 # initialize global vars
 TMPLOC = None
 SRCGISRC = None
@@ -157,8 +161,35 @@ def main():
         return grass.run_command('g.proj', epsg=options['epsg'],
                                  datum_trans=options['datum_trans'])
 
+    if layers:
+        vopts['layer'] = layers
+    if output:
+        vopts['output'] = output
+    vopts['snap'] = options['snap']
+
+    # try v.in.ogr directly
+    if flags['o'] or grass.run_command('v.in.ogr', input=OGRdatasource, flags='j',
+                                       errors='status', quiet=True, overwrite=overwrite,
+                                       **vopts) == 0:
+        try:
+            grass.run_command('v.in.ogr', input=OGRdatasource,
+                              flags=vflags, overwrite=overwrite, **vopts)
+            grass.message(
+                _("Input <%s> successfully imported without reprojection") %
+                OGRdatasource)
+            return 0
+        except CalledModuleError:
+            grass.fatal(_("Unable to import <%s>") % OGRdatasource)
+
     grassenv = grass.gisenv()
     tgtloc = grassenv['LOCATION_NAME']
+
+    # make sure target is not xy
+    if grass.parse_command('g.proj', flags='g')['name'] == 'xy_location_unprojected':
+        grass.fatal(
+            _("Coordinate reference system not available for current location <%s>") %
+            tgtloc)
+
     tgtmapset = grassenv['MAPSET']
     GISDBASE = grassenv['GISDBASE']
     tgtgisrc = os.environ['GISRC']
@@ -177,25 +208,6 @@ def main():
 
     # create temp location from input without import
     grass.verbose(_("Creating temporary location for <%s>...") % OGRdatasource)
-    if layers:
-        vopts['layer'] = layers
-    if output:
-        vopts['output'] = output
-    vopts['snap'] = options['snap']
-
-    # try v.in.ogr directly
-    if flags['o'] or grass.run_command('v.in.ogr', input=OGRdatasource, flags='j',
-                                       errors='status', quiet=True, overwrite=overwrite) == 0:
-        try:
-            grass.run_command('v.in.ogr', input=OGRdatasource,
-                              flags=vflags, overwrite=overwrite, **vopts)
-            grass.message(
-                _("Input <%s> successfully imported without reprojection") %
-                OGRdatasource)
-            return 0
-        except CalledModuleError:
-            grass.fatal(_("Unable to import <%s>") % OGRdatasource)
-
     try:
         grass.run_command('v.in.ogr', input=OGRdatasource,
                           location=TMPLOC, flags='i', quiet=True, overwrite=overwrite, **vopts)
@@ -211,18 +223,6 @@ def main():
             kwargs['datum_trans'] = options['datum_trans']
         grass.run_command('g.proj', flags='c', epsg=options['epsg'], **kwargs)
 
-    # switch to target location
-    os.environ['GISRC'] = str(tgtgisrc)
-
-    # make sure target is not xy
-    if grass.parse_command('g.proj', flags='g')['name'] == 'xy_location_unprojected':
-        grass.fatal(
-            _("Coordinate reference system not available for current location <%s>") %
-            tgtloc)
-
-    # switch to temp location
-    os.environ['GISRC'] = str(SRCGISRC)
-
     # print projection at verbose level
     grass.verbose(grass.read_command('g.proj', flags='p').rstrip(os.linesep))
 
