@@ -41,6 +41,10 @@ import string
 from grass.script.utils import separator, try_remove
 from grass.script import core as grass
 
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
+
 
 def cleanup():
     try_remove(tmp)
