@@ -79,9 +79,14 @@ import sys
 from grass.script.utils import try_remove
 from grass.script import core as grass
 try:
-    from urllib import urlopen
+    from urllib2 import urlopen, URLError, HTTPError
 except ImportError:
     from urllib.request import urlopen
+    from urllib.error import URLError, HTTPError
+
+# i18N
+import gettext
+gettext.install('grassmods', os.path.join(os.getenv("GISBASE"), 'locale'))
 
 
 def main():
@@ -100,12 +105,14 @@ def main():
     if options['maximum_features']:
         wfs_url += '&MAXFEATURES=' + options['maximum_features']
         if int(options['maximum_features']) < 1:
-            grass.fatal('Invalid maximum number of features')
+            # GTC Invalid WFS maximum features parameter
+            grass.fatal(_("Invalid maximum number of features"))
 
     if options['start_index']:
         wfs_url += '&STARTINDEX=' + options['start_index']
         if int(options['start_index']) < 1:
-            grass.fatal('Features begin with index "1"')
+            # GTC Invalid WFS start index parameter
+            grass.fatal(_('Features begin with index "1"'))
 
     if flags['r']:
         bbox = grass.read_command("g.region", flags='w').split('=')[1]
@@ -119,8 +126,18 @@ def main():
 
     grass.debug(wfs_url)
 
+    # GTC Downloading WFS features
     grass.message(_("Retrieving data..."))
-    inf = urlopen(wfs_url)
+    try:
+        inf = urlopen(wfs_url)
+    except HTTPError as e:
+        # GTC WFS request HTTP failure
+        grass.fatal(_("The server couldn't fulfill the request.\nError code: %s") % e.code)
+    except URLError as e:
+        # GTC WFS request network failure
+        grass.fatal(_("Failed to reach the server.\nReason: %s") % e.reason)
+        
+    
     outf = file(tmpxml, 'wb')
     while True:
         s = inf.read()
@@ -133,7 +150,7 @@ def main():
     if flags['l']:
         import shutil
         if os.path.exists('wms_capabilities.xml'):
-            grass.fatal('A file called "wms_capabilities.xml" already exists here')
+            grass.fatal(_('A file called "wms_capabilities.xml" already exists here'))
         # os.move() might fail if the temp file is on another volume, so we copy instead
         shutil.copy(tmpxml, 'wms_capabilities.xml')
         try_remove(tmpxml)
@@ -142,7 +159,7 @@ def main():
     grass.message(_("Importing data..."))
     try:
         grass.run_command('v.in.ogr', flags='o', input=tmpxml, output=out)
-        grass.message(_("Vector points map <%s> imported from WFS.") % out)
+        grass.message(_("Vector map <%s> imported from WFS.") % out)
     except:
         grass.message(_("WFS import failed"))
     finally:
