@@ -9,9 +9,15 @@
 #               raster dataset.
 # COPYRIGHT:    (C) 2013 by the GRASS Development Team
 #
-#               This program is free software under the GNU General Public
-#               License (version 2). Read the file COPYING that comes with GRASS
-#               for details.
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
 #
 #############################################################################
 
@@ -109,6 +115,7 @@ def main():
     size = options["size"]
     base = options["basename"]
     register_null = flags["n"]
+    use_raster_region = flags["r"]
     method = options["method"]
     nprocs = options["nprocs"]
     time_suffix = options["suffix"]
@@ -138,6 +145,9 @@ def main():
                                    method=method, overwrite=overwrite,
                                    quiet=True)
 
+    gregion_module =  pymod.Module("g.region", raster="dummy", run_=False,
+                                   finish_=False,)
+
     # The module queue for parallel execution
     process_queue = pymod.ParallelModuleQueue(int(nprocs))
 
@@ -165,11 +175,31 @@ def main():
 
         mod = copy.deepcopy(neighbor_module)
         mod(input=map.get_id(), output=new_map.get_id())
-        print(mod.get_bash())
-        process_queue.put(mod)
+
+        if use_raster_region is True:
+            reg = copy.deepcopy(gregion_module)
+            reg(raster=map.get_id())
+            print(reg.get_bash())
+            print(mod.get_bash())
+            mm = pymod.MultiModule([reg, mod], sync=False, set_temp_region=True)
+            process_queue.put(mm)
+        else:
+            print(mod.get_bash())
+            process_queue.put(mod)
 
     # Wait for unfinished processes
     process_queue.wait()
+    proc_list = process_queue.get_finished_modules()
+
+    # Check return status of all finished modules
+    error = 0
+    for proc in proc_list:
+        if proc.popen.returncode != 0:
+            grass.error(_("Error running module: %\n    stderr: %s") %(proc.get_bash(), proc.outputs.stderr))
+            error += 1
+
+    if error > 0:
+        grass.fatal(_("Error running modules."))
 
     # Open the new space time raster dataset
     ttype, stype, title, descr = sp.get_initial_values()
