@@ -19,7 +19,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <grass/gis.h>
-#include <grass/Vect.h>
+#include <grass/vector.h>
 #include <grass/glocale.h>
 #include <grass/dbmi.h>
 #include <grass/neta.h>
@@ -28,18 +28,17 @@
 int main(int argc, char *argv[])
 {
     struct Map_info In, Out;
-    static struct line_pnts *Points;
     struct line_cats *Cats;
     struct GModule *module;	/* GRASS module for parsing arguments */
     struct Option *map_in, *map_out;
-    struct Option *field_opt, *ncol;
-    struct Option *catset1_opt, *fieldset1_opt, *whereset1_opt;
-    struct Option *catset2_opt, *fieldset2_opt, *whereset2_opt;
+    struct Option *afield_opt, *nfield_opt, *abcol, *afcol, *ncol;
+    struct Option *catset1_opt, *whereset1_opt;
+    struct Option *catset2_opt, *whereset2_opt;
     int with_z;
-    int layer, mask_type;
+    int afield, nfield, mask_type;
     struct varray *varray_set1, *varray_set2;
     dglGraph_s *graph;
-    int i, nnodes, nlines, *flow, total_flow, nedges;
+    int i, nnodes, *flow, total_flow, nedges;
     struct ilist *set1_list, *set2_list, *cut;
     int *node_costs;
 
@@ -50,48 +49,65 @@ int main(int argc, char *argv[])
 
     /* initialize module */
     module = G_define_module();
-    module->keywords = _("vector, network, connectivity");
+    G_add_keyword(_("vector"));
+    G_add_keyword(_("network"));
+    G_add_keyword(_("connectivity"));
     module->description =
 	_("Computes vertex connectivity between two sets of nodes in the network.");
 
     /* Define the different options as defined in gis.h */
     map_in = G_define_standard_option(G_OPT_V_INPUT);
-    field_opt = G_define_standard_option(G_OPT_V_FIELD);
+
+    afield_opt = G_define_standard_option(G_OPT_V_FIELD);
+    afield_opt->key = "arc_layer";
+    afield_opt->answer = "1";
+    afield_opt->label = _("Arc layer");
+    afield_opt->guisection = _("Cost");
+
+    nfield_opt = G_define_standard_option(G_OPT_V_FIELD);
+    nfield_opt->key = "node_layer";
+    nfield_opt->answer = "2";
+    nfield_opt->label = _("Node layer");
+    nfield_opt->guisection = _("Cost");
+
+    afcol = G_define_standard_option(G_OPT_DB_COLUMN);
+    afcol->key = "arc_column";
+    afcol->required = NO;
+    afcol->description =
+	_("Arc forward/both direction(s) cost column (number)");
+    afcol->guisection = _("Cost");
+
+    abcol = G_define_standard_option(G_OPT_DB_COLUMN);
+    abcol->key = "arc_backward_column";
+    abcol->required = NO;
+    abcol->description = _("Arc backward direction cost column (number)");
+    abcol->guisection = _("Cost");
 
     map_out = G_define_standard_option(G_OPT_V_OUTPUT);
 
-    ncol = G_define_standard_option(G_OPT_COLUMN);
-    ncol->key = "ncolumn";
+    ncol = G_define_standard_option(G_OPT_DB_COLUMN);
+    ncol->key = "node_column";
     ncol->required = NO;
-    ncol->description = _("Name of node capacity column");
-
-    fieldset1_opt = G_define_standard_option(G_OPT_V_FIELD);
-    fieldset1_opt->key = "set1_layer";
-    fieldset1_opt->label = _("Set1 layer number or name");
-    fieldset1_opt->guisection = _("Set1");
+    ncol->description = _("Node cost column (number)");
+    ncol->guisection = _("Cost");
 
     catset1_opt = G_define_standard_option(G_OPT_V_CATS);
     catset1_opt->key = "set1_cats";
     catset1_opt->label = _("Set1 category values");
     catset1_opt->guisection = _("Set1");
 
-    whereset1_opt = G_define_standard_option(G_OPT_WHERE);
+    whereset1_opt = G_define_standard_option(G_OPT_DB_WHERE);
     whereset1_opt->key = "set1_where";
     whereset1_opt->label =
 	_("Set1 WHERE conditions of SQL statement without 'where' keyword");
     whereset1_opt->guisection = _("Set1");
 
-    fieldset2_opt = G_define_standard_option(G_OPT_V_FIELD);
-    fieldset2_opt->key = "set2_layer";
-    fieldset2_opt->description = _("Set2 layer number or name");
-    fieldset2_opt->guisection = _("Set2");
-
     catset2_opt = G_define_standard_option(G_OPT_V_CATS);
     catset2_opt->key = "set2_cats";
     catset2_opt->description = _("Set2 category values");
     catset2_opt->guisection = _("Set2");
 
-    whereset2_opt = G_define_standard_option(G_OPT_WHERE);
+    whereset2_opt = G_define_standard_option(G_OPT_DB_WHERE);
     whereset2_opt->key = "set2_where";
     whereset2_opt->label =
 	_("Set2 WHERE conditions of SQL statement without 'where' keyword");
@@ -103,11 +119,10 @@ int main(int argc, char *argv[])
     /* TODO: make an option for this */
     mask_type = GV_LINE | GV_BOUNDARY;
 
-    Points = Vect_new_line_struct();
     Cats = Vect_new_cats_struct();
 
     Vect_check_input_output_name(map_in->answer, map_out->answer,
-				 GV_FATAL_EXIT);
+				 G_FATAL_EXIT);
 
     Vect_set_open_level(2);
 
@@ -122,18 +137,23 @@ int main(int argc, char *argv[])
     }
 
     /* parse filter option and select appropriate lines */
-    layer = atoi(field_opt->answer);
+    afield = Vect_get_field_number(&In, afield_opt->answer);
+    nfield = Vect_get_field_number(&In, nfield_opt->answer);
 
     if (NetA_initialise_varray
-	(&In, atoi(fieldset1_opt->answer), GV_POINT, whereset1_opt->answer,
-	 catset1_opt->answer, &varray_set1) == 2)
-	G_fatal_error(_("Neither %s nor %s was given"), catset1_opt->key,
-		      whereset1_opt->key);
+	(&In, nfield, GV_POINT, whereset1_opt->answer,
+	 catset1_opt->answer, &varray_set1) <= 0) {
+	G_fatal_error(_("No features for %s selected. "
+			"Please check options '%s', '%s'."),
+			"set1", catset1_opt->key, whereset1_opt->key);
+    }
     if (NetA_initialise_varray
-	(&In, atoi(fieldset2_opt->answer), GV_POINT, whereset2_opt->answer,
-	 catset2_opt->answer, &varray_set2) == 2)
-	G_fatal_error(_("Neither %s nor %s was given"), catset2_opt->key,
-		      whereset2_opt->key);
+	(&In, nfield, GV_POINT, whereset2_opt->answer,
+	 catset2_opt->answer, &varray_set2) <= 0) {
+	G_fatal_error(_("No features for %s selected. "
+			"Please check options '%s', '%s'."),
+			"set2", catset2_opt->key, whereset2_opt->key);
+    }
 
     set1_list = Vect_new_list();
     set2_list = Vect_new_list();
@@ -141,7 +161,6 @@ int main(int argc, char *argv[])
     NetA_varray_to_nodes(&In, varray_set1, set1_list, NULL);
     NetA_varray_to_nodes(&In, varray_set2, set2_list, NULL);
 
-    nlines = Vect_get_num_lines(&In);
     nnodes = Vect_get_num_nodes(&In);
 
     if (set1_list->n_values == 0)
@@ -154,16 +173,18 @@ int main(int argc, char *argv[])
     Vect_hist_copy(&In, &Out);
     Vect_hist_command(&Out);
 
-    Vect_net_build_graph(&In, mask_type, 0, atoi(field_opt->answer),
-			 NULL, NULL, NULL, 0, 0);
-    graph = &(In.graph);
+    if (0 != Vect_net_build_graph(&In, mask_type, afield, nfield, afcol->answer,
+                                  abcol->answer, ncol->answer, 0, 0))
+        G_fatal_error(_("Unable to build graph for vector map <%s>"), Vect_get_full_name(&In));
+
+    graph = Vect_net_get_graph(&In);
 
     /*build new graph */
     if (ncol->answer) {
 	node_costs = (int *)G_calloc(nnodes + 1, sizeof(int));
 	if (!node_costs)
 	    G_fatal_error(_("Out of memory"));
-	NetA_get_node_costs(&In, layer, ncol->answer, node_costs);
+	NetA_get_node_costs(&In, nfield, ncol->answer, node_costs);
 	nedges = NetA_split_vertices(graph, &vg, node_costs);
 	G_free(node_costs);
     }
