@@ -16,7 +16,8 @@ struct Options {
 };
 
 struct Flags {
-    struct Flag *cat, *esristyle, *update, *nocat, *new, *append, *force2d, *multi;
+    struct Flag *cat, *esristyle, *update, *nocat, *new, *append,
+                *force2d, *multi, *list;
 };
 
 /* args.c */
@@ -28,8 +29,13 @@ int mk_att(int, struct field_info *, dbDriver *,
 	   int, int *, const char **, int, int,
 	   OGRFeatureH, int *);
 
+/* dsn.c */
+char *get_datasource_name(const char *, int);
+
 /* list.c */
 char *OGR_list_write_drivers();
+void list_formats(void);
+char *default_driver(void);
 
 /* create.c */
 void create_ogr_layer(const char *, const char *, const char *,
