@@ -35,7 +35,7 @@ int main(int argc, char *argv[])
     int num_to_export;
     int field;
     int overwrite, found;
-
+    
     struct GModule *module;
     struct Options options;
     struct Flags flags;
@@ -73,7 +73,8 @@ int main(int argc, char *argv[])
     OGRSpatialReferenceH Ogr_projection;
     char **papszDSCO = NULL, **papszLCO = NULL;
     int num_types;
-
+    char *dsn;
+    
     G_gisinit(argv[0]);
 
     /* Module options */
@@ -84,12 +85,17 @@ int main(int argc, char *argv[])
 
     module->label =
 	_("Exports a vector map layer to any of the supported OGR vector formats.");
-    module->description = _("By default a vector map layer is exported to Esri Shapefile format.");
+    module->description = _("By default a vector map layer is exported to OGC GeoPackage format.");
     module->overwrite = TRUE;
     
     /* parse & read options */
     parse_args(argc, argv, &options, &flags);
-    
+
+    if (flags.list->answer) {
+	list_formats();
+	exit(EXIT_SUCCESS);
+    }
+
     /* check for weird options */
     if (G_strncasecmp(options.dsn->answer, "PG:", 3) == 0 &&
         strcmp(options.format->answer, "PostgreSQL") != 0)
@@ -193,10 +199,6 @@ int main(int argc, char *argv[])
     if (!options.layer->answer) {
 	char xname[GNAME_MAX], xmapset[GMAPSET_MAX];
 
-	if (flags.append->answer)
-	    G_fatal_error(_("Appending to OGR layer requires option '%s'"),
-	                  options.layer->key);
-
 	if (G_name_is_fully_qualified(options.input->answer, xname, xmapset))
 	    options.layer->answer = G_store(xname);
 	else
@@ -280,6 +282,10 @@ int main(int argc, char *argv[])
 	    OSRMorphToESRI(Ogr_projection);
     }
 
+    dsn = NULL;
+    if (options.dsn->answer)
+        dsn = get_datasource_name(options.dsn->answer, TRUE);
+
     /* create new OGR layer in datasource */
     if (flags.new->answer) {
 	const char *name;
@@ -288,7 +294,7 @@ int main(int argc, char *argv[])
 	    options.layer->answer ? options.layer->answer : options.input->
 	    answer;
 
-	create_ogr_layer(options.dsn->answer, options.format->answer, name,
+	create_ogr_layer(dsn, options.format->answer, name,
 			 wkbtype, papszDSCO, papszLCO);
 
 	G_message(_("OGR layer <%s> created in datasource <%s> (format '%s')"),
@@ -464,22 +470,22 @@ int main(int argc, char *argv[])
     
     if (flags.append->answer) {
 	G_debug(1, "Append to OGR layer");
-	Ogr_ds = OGR_Dr_Open(Ogr_driver, options.dsn->answer, TRUE);
+	Ogr_ds = OGR_Dr_Open(Ogr_driver, dsn, TRUE);
 	
 	if (Ogr_ds == NULL) {
 	    G_debug(1, "Create OGR data source");
-	    Ogr_ds = OGR_Dr_CreateDataSource(Ogr_driver, options.dsn->answer,
+	    Ogr_ds = OGR_Dr_CreateDataSource(Ogr_driver, dsn,
 					     papszDSCO);
 	}
     }
     else {
 	if (flags.update->answer) {
 	    G_debug(1, "Update OGR data source");
-	    Ogr_ds = OGR_Dr_Open(Ogr_driver, options.dsn->answer, TRUE);
+	    Ogr_ds = OGR_Dr_Open(Ogr_driver, dsn, TRUE);
 	}
 	else {
 	    G_debug(1, "Create OGR data source");
-	    Ogr_ds = OGR_Dr_CreateDataSource(Ogr_driver, options.dsn->answer,
+	    Ogr_ds = OGR_Dr_CreateDataSource(Ogr_driver, dsn,
 					     papszDSCO);
 	}
     }
