@@ -17,7 +17,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
-#include <grass/Vect.h>
+#include <grass/vector.h>
 #include <grass/gis.h>
 #include <grass/glocale.h>
 #include "local_proto.h"
@@ -26,7 +26,7 @@ int write_vtk_head(FILE * fp, struct Map_info *Map)
 {
     G_debug(3, _("writeVTKHeader: Writing VTK-Header"));
     fprintf(fp, "# vtk DataFile Version 3.0\n");
-    fprintf(fp, "GRASS 6 vector map: %s\n", Map->name);
+    fprintf(fp, "GRASS GIS 7 vector map: %s\n", Map->name);
     fprintf(fp, "ASCII\n");
     fprintf(fp, "DATASET POLYDATA\n");	/*We are using polydata. If Volume data is supported, uGrid should be used */
     return (0);
