@@ -36,7 +36,7 @@ int area_relate_geos(struct Map_info *, const GEOSGeometry *,
 #endif
 
 /* select.c */
-void select_lines(struct Map_info *, int, int,
+int select_lines(struct Map_info *, int, int,
                   struct Map_info *, int, int,
                   int, int, const char *, int *, int*, int*);
 
