@@ -5,12 +5,13 @@
  * AUTHOR(S):    Original s.to.rast3: Jaro Hofierka, Geomodel s.r.o. (original contributor)
  *               9/2005 Upgrade to GRASS 6 by Radim Blazek
  *               Soeren Gebbert <soeren.gebbert gmx.de>
- * PURPOSE:      
- * COPYRIGHT:    (C) 1999-2007 by the GRASS Development Team
+ *               OGR support by Martin Landa <landa.martin gmail.com>
+ * PURPOSE:      Converts vector points to 3D raster
+ * COPYRIGHT:    (C) 1999-2010 by the GRASS Development Team
  *
- *               This program is free software under the GNU General Public
- *               License (>=v2). Read the file COPYING that comes with GRASS
- *               for details.
+ *               This program is free software under the GNU General
+ *               Public License (>=v2). Read the file COPYING that
+ *               comes with GRASS for details.
  *
  *****************************************************************************/
 #include <stdlib.h>
@@ -19,8 +20,8 @@
 #include <math.h>
 #include <grass/gis.h>
 #include <grass/glocale.h>
-#include <grass/G3d.h>
-#include <grass/Vect.h>
+#include <grass/raster3d.h>
+#include <grass/vector.h>
 #include <grass/dbmi.h>
 
 int main(int argc, char *argv[])
@@ -28,12 +29,12 @@ int main(int argc, char *argv[])
     struct GModule *module;
     struct Option *in_opt, *out_opt, *field_opt, *col_opt;
     int field;
-    G3D_Region region;
+    RASTER3D_Region region;
 
     struct Map_info Map;
     struct line_pnts *Points;
     struct line_cats *Cats;
-    void *map = NULL;
+    RASTER3D_Map *map = NULL;
 
     int nlines, line, nrec, ctype;
 
@@ -41,51 +42,49 @@ int main(int argc, char *argv[])
     dbDriver *Driver;
     dbCatValArray cvarr;
 
+    G_gisinit(argv[0]);
+
     module = G_define_module();
-    module->keywords = _("vector, volume, conversion");
-    module->description = _("Converts a binary GRASS vector map "
-			    "(only points) layer into a 3D GRASS raster map layer.");
+    G_add_keyword(_("vector"));
+    G_add_keyword(_("conversion"));
+    G_add_keyword(_("voxel"));
+    module->description = _("Converts a vector map "
+			    "(only points) into a 3D raster map.");
 
     in_opt = G_define_standard_option(G_OPT_V_INPUT);
 
-    out_opt = G_define_standard_option(G_OPT_R3_OUTPUT);
-
-    col_opt = G_define_option();
-    col_opt->key = "column";
-    col_opt->type = TYPE_STRING;
-    col_opt->key_desc = "name";
-    col_opt->required = YES;
-    col_opt->multiple = NO;
-    col_opt->description = _("Column name (type must be numeric)");
-
     field_opt = G_define_standard_option(G_OPT_V_FIELD);
 
-    G_gisinit(argv[0]);
+    out_opt = G_define_standard_option(G_OPT_R3_OUTPUT);
 
+    col_opt = G_define_standard_option(G_OPT_DB_COLUMN);
+    col_opt->required = YES;
+    col_opt->description = _("Name of attribute column (data type must be numeric)");
+    
     if (G_parser(argc, argv))
 	exit(EXIT_FAILURE);
+    
+    Rast3d_init_defaults();
 
-    if (G_legal_filename(out_opt->answer) < 0)
-	G_fatal_error(_("<%s> is an illegal file name"), out_opt->answer);
-
-    G3d_getWindow(&region);
-    G3d_readWindow(&region, NULL);
-
-    field = atoi(field_opt->answer);
+    Rast3d_get_window(&region);
 
     Vect_set_open_level(2);
-    Vect_open_old(&Map, in_opt->answer, "");
+    if (Vect_open_old2(&Map, in_opt->answer, "", field_opt->answer) < 0)
+	G_fatal_error(_("Unable to open vector map <%s>"), in_opt->answer);
+
+    field = Vect_get_field_number(&Map, field_opt->answer);
 
     db_CatValArray_init(&cvarr);
     Fi = Vect_get_field(&Map, field);
     if (Fi == NULL)
-	G_fatal_error(_("Unable to get layer info for vector map"));
+	G_fatal_error(_("Database connection not defined for layer <%s>"), field_opt->answer);
 
     Driver = db_start_driver_open_database(Fi->driver, Fi->database);
     if (Driver == NULL)
 	G_fatal_error(_("Unable to open database <%s> by driver <%s>"),
 		      Fi->database, Fi->driver);
-
+    db_set_error_handler_driver(Driver);
+    
     /* Note: do not check if the column exists in the table because it may be expression */
 
     nrec = db_select_CatValArray(Driver, Fi->table, Fi->key,
@@ -101,8 +100,8 @@ int main(int argc, char *argv[])
 
     db_close_database_shutdown_driver(Driver);
 
-    map = G3d_openCellNew(out_opt->answer, FCELL_TYPE,
-			  G3D_USE_CACHE_DEFAULT, &region);
+    map = Rast3d_open_new_opt_tile_size(out_opt->answer,
+			  RASTER3D_USE_CACHE_DEFAULT, &region, FCELL_TYPE, 32);
 
     if (map == NULL)
 	G_fatal_error(_("Unable to create output map"));
@@ -114,7 +113,9 @@ int main(int argc, char *argv[])
     for (line = 1; line <= nlines; line++) {
 	int type, cat, depth, row, col, ret;
 	double value;
-
+	
+	G_percent(line, nlines, 2);
+	
 	type = Vect_read_line(&Map, Points, Cats, line);
 	if (!(type & GV_POINT))
 	    continue;
@@ -123,18 +124,12 @@ int main(int argc, char *argv[])
 	if (cat < 0) {
 	    continue;
 	}
-
-	if (Points->x[0] < region.west || Points->x[0] > region.east
-	    || Points->y[0] < region.south || Points->y[0] > region.north
-	    || Points->z[0] < region.bottom || Points->z[0] > region.top) {
+        /* Check if the coordinates are located in the cube */
+	if (!Rast3d_is_valid_location(&(map->region), Points->y[0], Points->x[0], Points->z[0])) {
 	    continue;
 	}
-
-	/*Because the g3d lib is row oriented and counts therefore from north to south,
-	 * we have to do the same here*/
-	row = (int)floor((region.north - Points->y[0]) / region.ns_res);
-	col = (int)floor((Points->x[0] - region.west) / region.ew_res);
-	depth = (int)floor((Points->z[0] - region.bottom) / region.tb_res);
+        /* Convert the north, east and top coorindate into row, col and depth*/
+        Rast3d_location2coord2(&(map->region), Points->y[0], Points->x[0], Points->z[0], &col, &row, &depth);
 
 	if (ctype == DB_C_TYPE_INT) {
 	    int ivalue;
@@ -153,14 +148,13 @@ int main(int argc, char *argv[])
 
 	G_debug(3, "col,row,depth,val: %d %d %d %f", col, row, depth, value);
 
-	G3d_putFloat(map, col, row, depth, (float)value);
+	Rast3d_put_float(map, col, row, depth, (float)value);
     }
 
     Vect_close(&Map);
 
-    if (!G3d_closeCell(map))
+    if (!Rast3d_close(map))
 	G_fatal_error(_("Unable to close new 3d raster map"));
-
-
+    
     exit(EXIT_SUCCESS);
 }
