@@ -185,8 +185,10 @@ int readsites(void)
     if (nsites < 2) {
 	const char *name = Vect_get_full_name(&In);
 	Vect_close(&In);
-	G_fatal_error(n_("Found %d point/centroid in <%s>, but at least 2 are needed",
-                         "Found %d points/centroids in <%s>, but at least 2 are needed",
+	G_fatal_error(n_("Found %d point/centroid in <%s>, but at least 2 are needed. "
+	                 "Are the current region extents covering at least parts of the input map?",
+                         "Found %d points/centroids in <%s>, but at least 2 are needed. "
+			 "Are the current region extents covering at least parts of the input map?",
                          nsites),
 	              nsites, name);
     }
